; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands are given below. Delete, add, or modify as you wish.

;-| Super Motions |--------------------------------------------------------

; QCBHCF
[Command]
name = QCBHCF_a
command = ~D, B, D, F, a
time = 35

[Command]
name = QCBHCF_b
command = ~D, B, D, F, b
time = 35

[Command]
name = QCBHCF_ab
command = ~D, B, D, F, a+b
time = 35

[Command]
name = FATAL
command = ~D, B, D, B, a
time = 60


;-| Special Motions |------------------------------------------------------
;-----------------
; QCF
[Command]
name = QCF_a
command = ~D, F, a

[Command]
name = QCF_b
command = ~D, F, b

;-----------------
; QCB
[Command]
name = QCB_a
command = ~D, DB, B, a

[Command]
name = QCB_b
command = ~D, DB, B, b

;-----------------
; Uppercut
[Command]
name = uppercut_a
command = ~F, D, DF, a

[Command]
name = uppercut_b
command = ~F, D, DF, b

; MirrorUppercut
[Command]
name = upper_a
command = ~B, D, DB, a

[Command]
name = upper_b
command = ~B, D, DB, b

[Command]
name = upper_ab
command = ~B, D, DB, a+b

;-| Double Tap |-----------------------------------------------------------
[Command]
name = FF       ;Required (do not remove)
command = F, F
time = 10

[Command]
name = BB       ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = recovery ;Required (do not remove)
command = a+b
time = 1

[Command]
name = ab
command = a+b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = a
command = a
time = 1

[Command]
name = b
command = b
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = holdfwd  ;Required (do not remove)
command = /$F
time = 1

[Command]
name = holdback ;Required (do not remove)
command = /$B
time = 1

[Command]
name = holdup   ;Required (do not remove)
command = /$U
time = 1

[Command]
name = holddown ;Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in. 


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
;RunFwd
[State -1]
type = ChangeState
value = 100
trigger1 = command = FF
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;RunBack
[State -1]
type = ChangeState
value = 105
trigger1 = command = BB
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;supermove3
[State -1]
type = ChangeState
value = 4100
triggerall = command = QCBHCF_ab
triggerall = power >= 3000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 220
trigger4 = movecontact = 1
trigger5 = stateno = 240
trigger5 = movecontact = 1
trigger6 = stateno = 400
trigger6 = movecontact = 1

;supermove1
[State -1]
type = ChangeState
value = 3000
triggerall = command = QCBHCF_b
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 220
trigger4 = movecontact = 1
trigger5 = stateno = 240
trigger5 = movecontact = 1
trigger6 = stateno = 4000
trigger6 = movecontact = 1
trigger7 = stateno = 400
trigger7 = movecontact = 1

;supermove2
[State -1]
type = ChangeState
value = 4000
triggerall = command = QCBHCF_a
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 220
trigger4 = movecontact = 1
trigger5 = stateno = 240
trigger5 = movecontact = 1
trigger6 = stateno = 400
trigger6 = movecontact = 1

;---------------------------------------------------------------------------
;  --- (FATALITY) ---
[State -1]
type = ChangeState
value = 4500
triggerall = command = FATAL
triggerall = p2life <= 200
triggerall = P2Dist x <= 80
triggerall = P2StateType != A
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;  --- (TELEPORT_LONG) ---
[State -1]
type = ChangeState
value = 450
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = command = upper_ab

;  --- (TELEPORT_MEDIUM) ---
[State -1]
type = ChangeState
value = 460
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = command = upper_b

;  --- (TELEPORT_SHORT) ---
[State -1]
type = ChangeState
value = 470
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = command = upper_a

;  --- (BACKSPIN) ---
[State -1]
type = ChangeState
value = 200
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = command = QCF_a
trigger2 = stateno = 400
trigger2 = movecontact = 1
trigger3 = stateno = 410
trigger3 = movecontact = 1
trigger4 = stateno = 420
trigger4 = movecontact = 1

;  --- (ROCKET) ---
[State -1]
type = ChangeState
value = 210
triggerall = statetype = S
triggerall = numproj = 0
triggerall = ctrl = 1
trigger1 = command = QCB_b
trigger2 = stateno = 400
trigger2 = movecontact = 1
trigger3 = stateno = 410
trigger3 = movecontact = 1
trigger4 = stateno = 420
trigger4 = movecontact = 1

;  --- (ROCKET AIR) ---
[State -1]
type = ChangeState
value = 300
triggerall = statetype = A
triggerall = numproj = 0
triggerall = ctrl = 1
trigger1 = command = QCB_b

;  --- (FIRE) ---
[State -1]
type = ChangeState
value = 220
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = command = QCB_a
trigger2 = stateno = 400
trigger2 = movecontact = 1
trigger3 = stateno = 410
trigger3 = movecontact = 1
trigger4 = stateno = 420
trigger4 = movecontact = 1
trigger5 = stateno = 240
trigger5 = movecontact = 1

;  --- (ROLL) ---
[State -1]
type = ChangeState
value = 240
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = command = QCF_b
trigger2 = stateno = 400
trigger2 = movecontact = 1
trigger3 = stateno = 410
trigger3 = movecontact = 1
trigger4 = stateno = 420
trigger4 = movecontact = 1

;---------------------------------------------------------------------------
;  --- (CROUCH_X) ---
[State -1]
type = ChangeState
value = 420
triggerall = statetype = C
triggerall = ctrl = 1
trigger1 = command = ab
trigger2 = stateno = 410
trigger2 = movecontact = 1

;  --- (CROUCH_A) ---
[State -1]
type = ChangeState
value = 400
triggerall = statetype = C
triggerall = ctrl = 1
trigger1 = command = a
trigger2 = stateno = 400
trigger2 = time > 7

;  --- (CROUCH_B) ---
[State -1]
type = ChangeState
value = 410
triggerall = statetype = C
triggerall = ctrl = 1
trigger1 = command = b
trigger2 = stateno = 400
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;  --- (PUNCH_X) ---
[State -1]
type = ChangeState
value = 420
triggerall = command != holddown
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = command = ab
trigger2 = stateno = 410
trigger2 = movecontact = 1

;  --- (PUNCH_A) ---
[State -1]
type = ChangeState
value = 400
triggerall = command != holddown
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = command = a
trigger2 = stateno = 400
trigger2 = time > 7

;  --- (PUNCH_B) ---
[State -1]
type = ChangeState
value = 410
triggerall = command != holddown
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = command = b
trigger2 = stateno = 400
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;  --- (JUMP_PUNCH) ---
[State -1]
type = ChangeState
value = 405
triggerall = statetype = A
triggerall = ctrl = 1
trigger1 = command = a
trigger2 = command = b
trigger3 = command = ab

;===========================================================================
