; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted


;-| Super Motions |--------------------------------------------------------
[Command]
name = QCF_ab
command = ~D, DF, F, a+b

;-| Special Motions |------------------------------------------------------
[Command]
name = QCF_a
command = ~D, DF, F, a

[Command]
name = QCF_b
command = ~D, DF, F, b

[Command]
name = QCF_c
command = ~D, DF, F, c

[Command]
name = QCF_x
command = ~D, DF, F, x

[Command]
name = QCF_y
command = ~D, DF, F, y

[Command]
name = QCF_z
command = ~D, DF, F, z

[Command]
name = RDP_x
command = ~B, D, DB, x

[Command]
name = RDP_z
command = ~B, D, DB, z

[Command]
name = RDP_y
command = ~B, D, DB, y

[Command]
name = RDP_b
command = ~B, D, DB, b

[Command]
name = RDP_c
command = ~B, D, DB, c

[Command]
name = DP_x
command = ~F, D, DF, x

[Command]
name = DP_y
command = ~F, D, DF, y

[Command]
name = DP_z
command = ~F, D, DF, z

[Command]
name = HCF_x
command = ~B, BD, D, DF, F, x
time = 30

[Command]
name = HCF_y
command = ~B, DB, D, DF, F, y
time = 30

[Command]
name = HCF_z
command = ~B, DB, D, DF, F, z
time = 30

[Command]
name = QCB_a
command = ~D, DB, B, a

[Command]
name = QCB_b
command = ~D, DB, B, b

[Command]
name = QCB_c
command = ~D, DB, B, c

[Command]
name = QCB_x
command = ~D, DB, B, x

[Command]
name = QCB_y
command = ~D, DB, B, y

[Command]
name = QCB_z
command = ~D, DB, B, z

[Command]
name = QCF2_a
command = ~D, DF, F, D, DF, F, a
time = 30

[Command]
name = QCF2_b
command = ~D, DF, F, D, DF, F, b
time = 30

[Command]
name = QCF2_c
command = ~D, DF, F, D, DF, F, c
time = 30 

;-| Double Tap |-----------------------------------------------------------
[Command]
name = FF       ;Required (do not remove)
command = F, F
time = 10

[Command]
name = BB       ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = recovery ;Required (do not remove)
command = a+b
time = 1
[Command]
name = recovery
command = x+y
time = 1

[Command]
name = ab
command = a+b
time = 1

[Command]
name = xy
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = fwd_a
command = /F,a
time = 1

[Command]
name = fwd_b
command = /F,b
time = 1

[Command]
name = fwd_c
command = /F,c
time = 1

[Command]
name = downfwd_a
command = /DF,a
time = 1

[Command]
name = downfwd_b
command = /DF,b
time = 1

[Command]
name = back_a
command = /B,a
time = 1

[Command]
name = back_b
command = /B,b
time = 1

[Command]
name = back_c
command = /B,c
time = 1

[Command]
name = down_a
command = /$D,a
time = 1

[Command]
name = down_b
command = /$D,b
time = 1

[Command]
name = down_c
command = /$D,c
time = 1

[Command]
name = fwd_ab
command = /F, a+b
time = 1

[Command]
name = back_ab
command = /B, a+b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = a
command = a
time = 1

[Command]
name = b
command = b
time = 1

[Command]
name = c
command = c
time = 1

[Command]
name = x
command = x
time = 1

[Command]
name = y
command = y
time = 1

[Command]
name = z
command = z
time = 1

[Command]
name = s
command = s ;	Start!
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = holdfwd  ;Required (do not remove)
command = /$F
time = 1

[Command]
name = holdback ;Required (do not remove)
command = /$B
time = 1

[Command]
name = holdup   ;Required (do not remove)
command = /$U
time = 1

[Command]
name = holddown ;Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
;Superwaza A
;[State -1]
;type = ChangeState
;value = 3000
;triggerall = command = QCF_ab
;triggerall = power >= 1000
;trigger1 = statetype = S
;trigger1 = ctrl = 1
;trigger2 = statetype != A
;trigger2 = hitdefattr = SC, NA, SA
;trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;SHINRYUKEN!!!!!!! JAB version
[State -1]
type = ChangeState
value = 3500
triggerall = command = QCF2_a
triggerall = power >= 1000
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = hitdefattr = C, NA
trigger2 = movecontact = 1
trigger3 = stateno = 200 ; standing short
trigger3 = movecontact = 1
trigger4 = stateno = 205 ; standing jab
trigger4 = movecontact = 1
trigger5 = stateno = 210 ; standing forward
trigger5 = movecontact = 1
trigger6 = stateno = 215 ; standing strong
trigger6 = movecontact = 1
trigger7 = stateno = 1900 ; gut punch
trigger7 = movecontact = 1

;SHINRYUKEN!!!!!!! STRONG version
[State -1]
type = ChangeState
value = 3600
triggerall = command = QCF2_b
triggerall = power >= 2000
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = hitdefattr = C, NA
trigger2 = movecontact = 1
trigger3 = stateno = 200 ; standing short
trigger3 = movecontact = 1
trigger4 = stateno = 205 ; standing jab
trigger4 = movecontact = 1
trigger5 = stateno = 210 ; standing forward
trigger5 = movecontact = 1
trigger6 = stateno = 215 ; standing strong
trigger6 = movecontact = 1
trigger7 = stateno = 1900 ; gut punch
trigger7 = movecontact = 1

;SHINRYUKEN!!!!!!! FIERCE version
[State -1]
type = ChangeState
value = 3700
triggerall = command = QCF2_c
triggerall = power >= 3000
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = hitdefattr = C, NA
trigger2 = movecontact = 1
trigger3 = stateno = 200 ; standing short
trigger3 = movecontact = 1
trigger4 = stateno = 205 ; standing jab
trigger4 = movecontact = 1
trigger5 = stateno = 210 ; standing forward
trigger5 = movecontact = 1
trigger6 = stateno = 215 ; standing strong
trigger6 = movecontact = 1
trigger7 = stateno = 1900 ; gut punch
trigger7 = movecontact = 1

;--------------------------------------------------------------------------
;Forward Overhead Kick 
[State -1]
type = ChangeState
value = 700
trigger1 = command = fwd_b
trigger1 = statetype = S
trigger1 = ctrl = 1 

;===========================================================================
;---------------------------------------------------------------------------
; Jab Dragon Punch
[State -1]
type = ChangeState
value = 1500
triggerall = command = DP_x
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = hitdefattr = C, NA
trigger2 = movecontact = 1
trigger3 = stateno = 200 ; standing short
trigger3 = movecontact = 1
trigger4 = stateno = 205 ; standing jab
trigger4 = movecontact = 1
trigger5 = stateno = 210 ; standing forward
trigger5 = movecontact = 1
trigger5 = time < 8
trigger6 = stateno = 215 ; standing strong
trigger6 = movecontact = 1
trigger7 = stateno = 1900 ; gut punch
trigger7 = movecontact = 1

;---------------------------------------------------------------------------
; Strong Dragon Punch
[State -1]
type = ChangeState
value = 1600
triggerall = command = DP_y
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = hitdefattr = C, NA
trigger2 = movecontact = 1
trigger3 = stateno = 200 ; standing short
trigger3 = movecontact = 1
trigger4 = stateno = 205 ; standing jab
trigger4 = movecontact = 1
trigger5 = stateno = 210 ; standing forward
trigger5 = movecontact = 1
trigger5 = time < 8
trigger6 = stateno = 215 ; standing strong
trigger6 = movecontact = 1
trigger7 = stateno = 1900 ; gut punch
trigger7 = movecontact = 1

;---------------------------------------------------------------------------
; Fierce Dragon Punch
[State -1]
type = ChangeState
value = 1700
triggerall = command = DP_z
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = hitdefattr = C, NA
trigger2 = movecontact = 1
trigger3 = stateno = 200 ; standing short
trigger3 = movecontact = 1
trigger4 = stateno = 205 ; standing jab
trigger4 = movecontact = 1
trigger5 = stateno = 210 ; standing forward
trigger5 = movecontact = 1
trigger5 = time < 8
trigger6 = stateno = 215 ; standing strong
trigger6 = movecontact = 1
trigger7 = stateno = 1900 ; gut punch
trigger7 = movecontact = 1

;--------------------------------------------------------------------------
; Gut Punch! (Incomplete DP actually) I love it so much! ^_^
[State -1]
type = ChangeState
value = 1900
triggerall = command = RDP_z
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = hitdefattr = C, NA
trigger2 = movecontact = 1
trigger3 = stateno = 200 ; standing short
trigger3 = movecontact = 1
trigger4 = stateno = 205 ; standing jab
trigger4 = movecontact = 1
trigger5 = stateno = 210 ; standing forward
trigger5 = movecontact = 1
trigger5 = time < 8
trigger6 = stateno = 215 ; standing strong
trigger6 = movecontact = 1

; Gut Punch Continue
[State -1]
type = ChangeState
value = 1910
trigger1 = command = RDP_z
trigger1 = stateno = 1900
trigger1 = movecontact = 1

;---------------------------------------------------------------------------
; Dan's Gale Kick
[State -1]
type = ChangeState
value = 1300
triggerall = command = RDP_b
triggerall = NumProjID8 = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200	; Standing Short
trigger2 = movecontact = 1
trigger2 = time > 0
trigger3 = stateno = 205	; Standing Jab
trigger3 = movecontact = 1
trigger3 = time > 0
trigger4 = stateno = 215	; Standing Strong
trigger4 = movecontact = 1
trigger4 = time > 0
trigger5 = stateno = 210	; Standing Forward
trigger5 = movecontact = 1
trigger5 = time < 8
trigger6 = hitdefattr = C, NA
trigger6 = movecontact = 1
trigger6 = time > 0
trigger7 = stateno = 1900	; Gut Punch (1)
trigger7 = movecontact = 1
trigger7 = time > 0

;---------------------------------------------------------------------------
; Ryu's Hurricane Kick Striker
[State -1]
type = ChangeState
value = 1350
triggerall = command = RDP_c
triggerall = NumProjID4 = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200	; Standing Short
trigger2 = movecontact = 1
trigger2 = time > 0
trigger3 = stateno = 205	; Standing Jab
trigger3 = movecontact = 1
trigger3 = time > 0
trigger4 = stateno = 215	; Standing Strong
trigger4 = movecontact = 1
trigger4 = time > 0
trigger5 = stateno = 210	; Standing Forward
trigger5 = movecontact = 1
trigger5 = time < 8
trigger6 = hitdefattr = C, NA
trigger6 = movecontact = 1
trigger6 = time > 0
trigger7 = stateno = 1900	; Gut Punch (1)
trigger7 = movecontact = 1
trigger7 = time > 0

;===========================================================================
;Ken's Hurricane Kick - Short Kick (GROUND version)
[State -1]

type = ChangeState
value = 1800
triggerall = command = QCB_a
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = hitdefattr = C, NA
trigger2 = movecontact = 1
trigger3 = stateno = 200 ; standing short
trigger3 = movecontact = 1
trigger4 = stateno = 205 ; standing jab
trigger4 = movecontact = 1
trigger5 = stateno = 210 ; standing forward
trigger5 = movecontact = 1
trigger5 = time < 8
trigger6 = stateno = 215 ; standing strong
trigger6 = movecontact = 1

;---------------------------------------------------------------------------
;Ken's Hurricane Kick - Forward Kick (GROUND version)
[State -1]

type = ChangeState
value = 1810
triggerall = command = QCB_b
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = hitdefattr = C, NA
trigger2 = movecontact = 1
trigger3 = stateno = 200 ; standing short
trigger3 = movecontact = 1
trigger4 = stateno = 205 ; standing jab
trigger4 = movecontact = 1
trigger5 = stateno = 210 ; standing forward
trigger5 = movecontact = 1
trigger5 = time < 8
trigger6 = stateno = 215 ; standing strong
trigger6 = movecontact = 1

;---------------------------------------------------------------------------
;Ken's Hurricane Kick - RoundHouse Kick (GROUND version)
[State -1]

type = ChangeState
value = 1820
triggerall = command = QCB_c
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = hitdefattr = C, NA
trigger2 = movecontact = 1
trigger3 = stateno = 200 ; standing short
trigger3 = movecontact = 1
trigger4 = stateno = 205 ; standing jab
trigger4 = movecontact = 1
trigger5 = stateno = 210 ; standing forward
trigger5 = movecontact = 1
trigger5 = time < 8
trigger6 = stateno = 215 ; standing strong
trigger6 = movecontact = 1

;===========================================================================
;Ken's Hurricane Kick - SHORT AIR version
[State -1]

type = ChangeState
value = 1850
triggerall = command = QCB_a
triggerall = statetype = A
trigger1 = ctrl = 1

;--------------------------------------------------------------------
;Ken's Hurricane Kick - FORWARD AIR version
[State -1]

type = ChangeState
value = 1851
triggerall = command = QCB_b
triggerall = statetype = A
trigger1 = ctrl = 1

;--------------------------------------------------------------------
;Ken's Hurricane Kick - RoundHouse AIR version
[State -1]

type = ChangeState
value = 1852
triggerall = command = QCB_c
triggerall = statetype = A
trigger1 = ctrl = 1

;===========================================================================
;---------------------------------------------------------------------------
;Ken Fireball! - jab punch
[State -1]

type = ChangeState
value = 1000
triggerall = command = QCF_x
triggerall = NumProjID3 = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger2 = time > 0
trigger3 = stateno = 205	; Standing Jab
trigger3 = movecontact = 1
trigger3 = time > 0
trigger4 = stateno = 215
trigger4 = movecontact = 1
trigger4 = time > 0
trigger5 = stateno = 210	; Standing Forward
trigger5 = movecontact = 1
trigger5 = time < 8
trigger6 = stateno = 400	; Crouching Short
trigger6 = movecontact = 1
trigger6 = time > 0
trigger7 = stateno = 405	; Crouching Jab
trigger7 = movecontact = 1
trigger7 = time > 0
trigger8 = stateno = 410	; Crouching Forward
trigger8 = movecontact = 1
trigger8 = time > 0
trigger9 = stateno = 415	; Crouching Strong
trigger9 = movecontact = 1
trigger9 = time > 0
trigger10 = stateno = 425	; Crouching Fierce
trigger10 = movecontact = 1
trigger10 = time > 0
trigger11 = stateno = 420	; Crouching Roundhouse
trigger11 = movecontact = 1
trigger11 = time > 0

;---------------------------------------------------------------------------
;Ken Fireball - mid punch
[State -1]

type = ChangeState
value = 1001
triggerall = command = QCF_y
triggerall = NumProjID3 = 0
trigger1 = stateno != 1006
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200	; Standing Short
trigger2 = movecontact = 1
trigger2 = time > 0
trigger3 = stateno = 205	; Standing Jab
trigger3 = movecontact = 1
trigger3 = time > 0
trigger4 = stateno = 215	; Standing Strong
trigger4 = movecontact = 1
trigger4 = time > 0
trigger5 = stateno = 210	; Standing Forward
trigger5 = movecontact = 1
trigger5 = time < 8
trigger6 = stateno = 400	; Crouching Short
trigger6 = movecontact = 1
trigger6 = time > 0
trigger7 = stateno = 405	; Crouching Jab
trigger7 = movecontact = 1
trigger7 = time > 0
trigger8 = stateno = 410	; Crouching Forward
trigger8 = movecontact = 1
trigger8 = time > 0
trigger9 = stateno = 415	; Crouching Strong
trigger9 = movecontact = 1
trigger9 = time > 0
trigger10 = stateno = 425	; Crouching Fierce
trigger10 = movecontact = 1
trigger10 = time > 0
trigger11 = stateno = 420	; Crouching Roundhouse
trigger11 = movecontact = 1
trigger11 = time > 0

;---------------------------------------------------------------------------
;Ken Fireball - fierce 
[State -1]

type = ChangeState
value = 1002
triggerall = command = QCF_z
triggerall = NumProjID3 = 0
trigger1 = stateno != 1006
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger2 = time > 0
trigger3 = stateno = 205	; Standing Jab
trigger3 = movecontact = 1
trigger3 = time > 0
trigger4 = stateno = 215	; Standing Strong
trigger4 = movecontact = 1
trigger4 = time > 0
trigger5 = stateno = 210	; Standing Forward
trigger5 = movecontact = 1
trigger5 = time < 8
trigger6 = stateno = 400	; Crouching Short
trigger6 = movecontact = 1
trigger6 = time > 0
trigger7 = stateno = 405	; Crouching Jab
trigger7 = movecontact = 1
trigger7 = time > 0
trigger8 = stateno = 410	; Crouching Forward
trigger8 = movecontact = 1
trigger8 = time > 0
trigger9 = stateno = 415	; Crouching Strong
trigger9 = movecontact = 1
trigger9 = time > 0
trigger10 = stateno = 425	; Crouching Fierce
trigger10 = movecontact = 1
trigger10 = time > 0
trigger11 = stateno = 420	; Crouching Roundhouse
trigger11 = movecontact = 1
trigger11 = time > 0

;===========================================================================
;---------------------------------------------------------------------------
;Dan Fireball!
[State -1]

type = ChangeState
value = 1325
triggerall = command = RDP_x
triggerall = NumProjID8 = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200	; Standing Short
trigger2 = movecontact = 1
trigger2 = time > 0
trigger3 = stateno = 205	; Standing Jab
trigger3 = movecontact = 1
trigger3 = time > 0
trigger4 = stateno = 215	; Standing Strong
trigger4 = movecontact = 1
trigger4 = time > 0
trigger5 = stateno = 210	; Standing Forward
trigger5 = movecontact = 1
trigger5 = time < 8
trigger6 = hitdefattr = C, NA
trigger6 = movecontact = 1
trigger6 = time > 0
trigger7 = stateno = 1900	; Gut Punch (1)
trigger7 = movecontact = 1
trigger7 = time > 0

;---------------------------------------------------------------------------
;Ryu Fireball!
[State -1]

type = ChangeState
value = 1006
triggerall = command = RDP_y
triggerall = NumProjID4 = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200	; Standing Short
trigger2 = movecontact = 1
trigger2 = time > 0
trigger3 = stateno = 205	; Standing Jab
trigger3 = movecontact = 1
trigger3 = time > 0
trigger4 = stateno = 215	; Standing Strong
trigger4 = movecontact = 1
trigger4 = time > 0
trigger5 = stateno = 210	; Standing Forward
trigger5 = movecontact = 1
trigger5 = time < 8
trigger6 = hitdefattr = C, NA
trigger6 = movecontact = 1
trigger6 = time > 0
trigger7 = stateno = 1900	; Gut Punch (1)
trigger7 = movecontact = 1
trigger7 = time > 0

;===========================================================================
; Jab Roll (x)
[State -1]
type = ChangeState
value = 1200
triggerall = command = QCB_x
trigger1 = Statetype != A
trigger1 = ctrl = 1
trigger2 = hitdefattr = C, NA
trigger2 = movecontact = 1
trigger3 = stateno = 200 ; standing short
trigger3 = movecontact = 1
trigger4 = stateno = 205 ; standing jab
trigger4 = movecontact = 1
trigger5 = stateno = 210 ; standing forward
trigger5 = movecontact = 1
trigger5 = time < 8
trigger6 = stateno = 215 ; standing strong
trigger6 = movecontact = 1
trigger7 = stateno = 1900 ; gut punch
trigger7 = movecontact = 1

; Strong Roll (y)
[State -1]
type = ChangeState
value = 1210
triggerall = command = QCB_y
trigger1 = Statetype != A
trigger1 = ctrl = 1
trigger2 = hitdefattr = C, NA
trigger2 = movecontact = 1
trigger3 = stateno = 200 ; standing short
trigger3 = movecontact = 1
trigger4 = stateno = 205 ; standing jab
trigger4 = movecontact = 1
trigger5 = stateno = 210 ; standing forward
trigger5 = movecontact = 1
trigger5 = time < 8
trigger6 = stateno = 215 ; standing strong
trigger6 = movecontact = 1
trigger7 = stateno = 1900 ; gut punch
trigger7 = movecontact = 1

; Fierce Roll (z)
[State -1]
type = ChangeState
value = 1220
triggerall = command = QCB_z
trigger1 = Statetype != A
trigger1 = ctrl = 1
trigger2 = hitdefattr = C, NA
trigger2 = movecontact = 1
trigger3 = stateno = 200 ; standing short
trigger3 = movecontact = 1
trigger4 = stateno = 205 ; standing jab
trigger4 = movecontact = 1
trigger5 = stateno = 210 ; standing forward
trigger5 = movecontact = 1
trigger5 = time < 8
trigger6 = stateno = 215 ; standing strong
trigger6 = movecontact = 1
trigger7 = stateno = 1900 ; gut punch
trigger7 = movecontact = 1

;===========================================================================
;---------------------------------------------------------------------------
; Roll Fowawrd / Run Forward
[State -1]
type = ChangeState
value = 100
trigger1 = command = FF
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;RunBack
[State -1]
type = ChangeState
value = 105
trigger1 = command = BB
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Taunt
[State -1]
type = ChangeState
value = 195
trigger1 = command = s
trigger1 = statetype = S
;trigger1 = stateno != 195
trigger1 = ctrl = 1
;---------------------------------------------------------------------------

;Stand_Throw
[State -1]
type = ChangeState
value = 900
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = command = fwd_ab  ;Command
trigger2 = command = back_ab ;Command
trigger3 = command = fwd_b   ;Near, p2 stand
trigger3 = stateno != 100    ;Not running
trigger3 = p2bodydist X < 3
trigger3 = p2statetype = S
trigger3 = p2movetype != H
trigger4 = command = fwd_b   ;Near, p2 crouch
trigger4 = stateno != 100    ;Not running
trigger4 = p2bodydist X < 3
trigger4 = p2statetype = C
trigger4 = p2movetype != H
trigger5 = command = back_b  ;Near, p2 stand
trigger5 = p2bodydist X < 5
trigger5 = p2statetype = S
trigger5 = p2movetype != H
trigger6 = command = back_b  ;Near, p2 crouch
trigger6 = p2bodydist X < 5
trigger6 = p2statetype = C
trigger6 = p2movetype != H

;---------------------------------------------------------------------------
;Air_Throw1
[State -1]
type = ChangeState
value = 950
triggerall = statetype = A
triggerall = ctrl = 1
trigger1 = command = fwd_ab
trigger2 = command = back_ab
;---------------------------
;Air_Throw1 (second set of commands)
[State -1]
type = ChangeState
value = 950
triggerall = statetype = A
triggerall = ctrl = 1
triggerall = p2bodydist X < 9
triggerall = p2bodydist Y > -22
triggerall = p2bodydist Y < 22
triggerall = p2statetype = A
triggerall = p2movetype != H
trigger1 = command = fwd_b
trigger2 = command = back_b

;===========================================================================
;---------------------------------------------------------------------------
;Stand_A Short
[State -1]
type = ChangeState
value = 200
triggerall = command = a
triggerall = command != holddown
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 205
trigger2 = time > 4
trigger3 = stateno = 405
trigger3 = time > 4
trigger4 = stateno = 400
trigger3 = time > 4

;---------------------------------------------------------------------------
;Stand_X Jab
[State -1]
type = ChangeState
value = 205
triggerall = command = x
triggerall = command != holddown
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 205
trigger2 = time > 5

;---------------------------------------------------------------------------
;Stand_B Forward Kick
[State -1]
type = ChangeState
value = 210
triggerall = command = b
triggerall = command != holddown
trigger1 = statetype = S
trigger1 = ctrl = 1
;trigger2 = stateno = 200
;trigger2 = movecontact = 1

;Stand_B Executed by QCF_B
[State -1]
type = ChangeState
value = 210
triggerall = command = QCF_b
;triggerall = command != holddown
trigger1 = stateno = 205 ; s.jab
trigger1 = ctrl = 0
trigger1 = time > 3
;trigger1 = movecontact = 1
trigger2 = stateno = 200 ; s.short
trigger2 = ctrl = 0
trigger2 = time > 3
;trigger2 = movecontact = 1
trigger3 = stateno = 215 ; s.strong
trigger3 = ctrl = 0
trigger3 = time > 3
;trigger3 = movecontact = 1
trigger4 = stateno = 405 ; c.jab
trigger4 = ctrl = 0
trigger4 = time > 3
trigger5 = stateno = 400 ; c.short
trigger5 = ctrl = 0
trigger5 = time > 3
trigger6 = stateno = 410 ; c.forward
trigger6 = ctrl = 0
trigger6 = time > 3
trigger7 = stateno = 415 ; c.strong
trigger7 = ctrl = 0
trigger7 = time > 3
trigger8 = stateno = 425 ; c.fierce
trigger8 = ctrl = 0
trigger8 = time > 3
trigger9 = stateno = 420 ; c.roundhouse
trigger9 = movecontact = 1
trigger9 = ctrl = 0
trigger9 = time > 3

;---------------------------------------------------------------------------
;Stand_Y Strong
[State -1]
type = ChangeState
value = 215
triggerall = command = y
triggerall = command != holddown
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Standing Launcher_C Roundhouse
[State -1]
type = Changestate
value = 650
triggerall = stateno != 220
triggerall = p2bodydist X <= 40
triggerall = command != holddown
trigger1 = command = c
trigger1 = statetype = S
trigger1 = ctrl = 1

;Stand_C Roundhouse
[State -1]
type = ChangeState
value = 220
triggerall = command = c
triggerall = command != holddown
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Stand_Z Fierce
[State -1]
type = ChangeState
value = 225
triggerall = command = z
triggerall = command != holddown
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Crouch_A Short
[State -1]
type = ChangeState
value = 400
triggerall = command = a
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 400
trigger2 = time > 6
trigger3 = stateno = 405
trigger3 = movecontact = 1
trigger3 = time > 5

;---------------------------------------------------------------------------
;Crouch_X Jab
[State -1]
type = ChangeState
value = 405
triggerall = command = x
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 405
trigger2 = time > 6
trigger3 = stateno = 400
trigger3 = movecontact = 1
trigger3 = time > 5

;---------------------------------------------------------------------------
;Crouch_B Forward
[State -1]
type = ChangeState
value = 410
triggerall = command = b
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
;trigger2 = stateno = 400 ;crouch_a
;trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;Crouch_Y Strong
[State -1]
type = ChangeState
value = 415
triggerall = command = y
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Crouch_C Roundhouse
[State -1]
type = ChangeState
value = 420
triggerall = command = c
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Crouch_Z Fierce
[State -1]
type = ChangeState
value = 425
triggerall = command = z
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jump_A Short Forward/Backwards
[State -1]
type = ChangeState
value = 600
triggerall = Vel X != 0
trigger1 = command = a
trigger1 = statetype = A
trigger1 = ctrl = 1
;trigger2 = command = a   ;-------
;trigger2 = stateno = 600 ;jump_a
;trigger2 = statetime >= 6
trigger2 = command = a
trigger2 = stateno = 605 ; jump_x jab
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;Jump_A Short Neutral
[State -1]
type = ChangeState
value = 603
trigger1 = command = a
trigger1 = Statetype = A
trigger1 = ctrl = 1
trigger2 = command = a
trigger2 = stateno = 605 ; jump_x jab
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;Jump_X Jab
[State -1]
type = ChangeState
value = 605
;triggerall = Vel X != 0
trigger1 = command = x
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = x
trigger2 = stateno = 600 ; jump_a short
trigger2 = movecontact = 1
trigger3 = command = x
trigger3 = stateno = 603 ; jump_a short neutral
trigger3 = movecontact = 1

;---------------------------------------------------------------------------
;Jump_B Forward Kick
[State -1]
type = ChangeState
value = 610
triggerall = Vel X != 0
trigger1 = command = b
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = b
trigger2 = stateno = 600 ; jump_a short
trigger2 = movecontact = 1
trigger3 = command = b
trigger3 = stateno = 603 ; jump_a short neutral
trigger3 = movecontact = 1
trigger4 = command = b
trigger4 = stateno = 605 ; jump_x jab
trigger4 = movecontact = 1

;Jump_B Nuetral Forward Kick
[State -1]
type = ChangeState
value = 613
trigger1 = command = b
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = b
trigger2 = stateno = 600 ; jump_a short
trigger2 = movecontact = 1
trigger3 = command = b
trigger3 = stateno = 603 ; jump_a short neutral
trigger3 = movecontact = 1
trigger4 = command = b
trigger4 = stateno = 600 ; jump_x jab
trigger4 = movecontact = 1

;--------------------------------------------------------------------------
;Jump_Y Strong
[State -1]
type = ChangeState
value = 615
trigger1 = command = y
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = y
trigger2 = stateno = 600
trigger2 = movecontact = 1 ; jump_A Short
trigger3 = command = y
trigger3 = stateno = 603 ; jump_A Short Neutral
trigger3 = movecontact = 1
trigger4 = command = y
trigger4 = stateno = 605 ; jump_X Jab
trigger4 = movecontact = 1

;--------------------------------------------------------------------------
;Jump_C RoundHouse Non-Neutral
[State -1]
type = ChangeState
value = 620
triggerall = Vel X != 0
trigger1 = command = c
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = c
trigger2 = stateno = 610 ; jump forward kick
trigger2 = movecontact = 1
trigger3 = command = c
trigger3 = stateno = 613 ; jump forward neutral kick
trigger3 = movecontact = 1
trigger4 = command = c
trigger4 = stateno = 615 ; jumping strong
trigger4 = movecontact = 1

;Jump_C RoundHouse Neutral
[State -1]
type = ChangeState
value = 623
trigger1 = command = c
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = c
trigger2 = stateno = 610 ; jump forward kick
trigger2 = movecontact = 1
trigger3 = command = c
trigger3 = stateno = 613 ; jump forward neutral kick
trigger3 = movecontact = 1
trigger4 = command = c
trigger4 = stateno = 615 ; jumping strong
trigger4 = movecontact = 1

;--------------------------------------------------------------------------
;Jump_Z Fierce
[State -1]
type = ChangeState
value = 625
trigger1 = command = z
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = z
trigger2 = stateno = 610 ; jump forward kick
trigger2 = movecontact = 1
trigger3 = command = z
trigger3 = stateno = 613 ; jump forward neutral kick
trigger3 = movecontact = 1
trigger4 = command = z
trigger4 = stateno = 615 ; jumping strong
trigger4 = movecontact = 1

;--------------------------------------------------------------------------

