; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands are given below. Delete, add, or modify as you wish.

[command]
name = dm8
command = ~D, B, D, B, a
time = 40

[command]
name = dm7
command = ~D, B, D, B, x
time = 40

[Command]
name = qcf_qcf_b
command = ~D, F, D, F, b
time = 40

[Command]
name = cat_x
command = ~D, F, D, F, x
time = 40

[Command]
name = qcf_qcf_y
command = ~D, F, D, F, y
time = 40

[Command]
name = cat_a
command = ~D, F, D, F, a
time = 40


[Command]
name = shield_y
command = ~D, F, a

[Command]
name = shield_x
command = ~D, F, x

[command]
name = upper_h
command = ~F,D,F,b
time = 20

[command]
name = upper_y
command = ~F,D,F,y
time = 20

[Command]
name = frente_a
command = /F,a
time = 1

[Command]
name = frente_b
command = /F,b
time = 1

[Command]
name = VFrentex
command = /$F, x
time = 1

[Command]
name = Vtrazx
command = /$B, x
time = 1

[Command]
name = catch 
command = ~D, B, F,x
time = 25

[Command]
name = catch 
command = ~D, B, F,a
time = 25

[Command]
name = fwd_roll
command = /F, z
time = 1

[Command]
name = back_roll
command = /B, z
time = 1

;-| Double Tap |-----------------------------------------------------------
[Command]
name = FF       ;Required (do not remove)
command = F, F
time = 10

[Command]
name = BB       ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = recovery ;Required (do not remove)
command = a+b
time = 1

[Command]
name = ab
command = a+b
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = fwd_a
command = /F,a
time = 1

[Command]
name = fwd_b
command = /F,b
time = 1

[Command]
name = fwd_c
command = /F,c
time = 1

[Command]
name = fwd_x
command = /F,x
time = 1

[Command]
name = fwd_y
command = /F,y
time = 1

[Command]
name = fwd_z
command = /F,z
time = 1

[Command]
name = back_a
command = /B,a
time = 1

[Command]
name = back_b
command = /B,b
time = 1

[Command]
name = back_c
command = /B,c
time = 1

[Command]
name = down_a
command = /$D,a
time = 1

[Command]
name = down_b
command = /$D,b
time = 1

[Command]
name = down_c
command = /$D,c
time = 1

[Command]
name = fwd_ab
command = /F, a+b
time = 1

[Command]
name = back_ab
command = /B, a+b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = a
command = a
time = 1

[Command]
name = b
command = b
time = 1

[Command]
name = c
command = c
time = 1

[Command]
name = x
command = x
time = 1

[Command]
name = y
command = y
time = 1

[Command]
name = z
command = z
time = 1

;-| Hold Button |-----------------------------------------------------------
[Command]
name = hold_x
command = /x
time = 1

[Command]
name = hold_y
command = /y
time = 1

[Command]
name = hold_z
command = /z
time = 1

[Command]
name = hold_a
command = /a
time = 1

[Command]
name = hold_b
command = /b
time = 1

[Command]
name = hold_c
command = /c
time = 1

[Command]
name = hold_s
command = /s
time = 1


;-| Hold Dir |--------------------------------------------------------------


[Command]
name = holdfwd  ;Required (do not remove)
command = /$F
time = 1

[Command]
name = holdback ;Required (do not remove)
command = /$B
time = 1

[Command]
name = holdup   ;Required (do not remove)
command = /$U
time = 1

[Command]
name = holddown ;Required (do not remove)
command = /$D
time = 1


;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in. 


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;---------------------------------------------------------------------------
; Electriza mega shock
[State -1]
type = ChangeState
value = 1311
triggerall = command = dm7
triggerall = power >= 2000
;triggerall = statetype != A
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = hitdefattr = SC, NA, SA
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
; Electriza mega shock
[State -1]
type = ChangeState
value = 1300
triggerall = command = dm8
triggerall = power >= 1000
;triggerall = statetype != A
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = hitdefattr = SC, NA, SA
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
; Ge shiki kake hou rin
[State -1]
type = ChangeState
value = 2300
triggerall   = command = qcf_qcf_b
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = hitdefattr = SC, NA, SA
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
; Especial c/ Chute
[State -1]
type = ChangeState
value = 2320
triggerall   = command = qcf_qcf_y
triggerall = power >= 2000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = hitdefattr = SC, NA, SA
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
; Agarro
[State -1]
type = ChangeState
value = 1050
triggerall = command = catch
;trigger1 = statetype != A
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Especial Fraco
[State -1]
type = ChangeState
value = 1021
triggerall = command = cat_a
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = hitdefattr = SC, NA, SA
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
; Especial Forte
[State -1]
type = ChangeState
value = 1022
triggerall = command = cat_x
triggerall = power >= 2000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = hitdefattr = SC, NA, SA
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;Shield_Y
[State -1]
type = ChangeState
value = 1200
triggerall = command = shield_y
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger2 = movehit = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger3 = movehit = 1
trigger4 = stateno = 206
trigger4 = movecontact = 1
;trigger4 = movehit = 1
trigger5 = stateno = 207
trigger5 = movecontact = 1
trigger5 = movehit = 1
trigger6 = stateno = 210
trigger6 = movecontact = 1
trigger6 = movehit = 1
trigger7 = stateno = 217
trigger7 = movecontact = 1
trigger7 = movehit = 1
trigger8 = stateno = 218
trigger8 = movecontact = 1
trigger8 = movehit = 1
trigger9 = stateno = 400
trigger9 = movecontact = 1
trigger9 = movehit = 1
trigger10 = stateno = 405
trigger10 = movecontact = 1
trigger10 = movehit = 1
trigger11 = stateno = 410
trigger11 = movecontact = 1
trigger11 = movehit = 1

;---------------------------------------------------------------------------
;Shield_Y
[State -1]
type = ChangeState
value = 1201
triggerall = command = shield_x
;triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 206
trigger4 = movecontact = 1
trigger5 = stateno = 207
trigger5 = movecontact = 1
trigger6 = stateno = 210
trigger6 = movecontact = 1
trigger7 = stateno = 217
trigger7 = movecontact = 1
trigger8 = stateno = 218
trigger8 = movecontact = 1
trigger9 = stateno = 400
trigger9 = movecontact = 1
trigger10 = stateno = 405
trigger10 = movecontact = 1
trigger11 = stateno = 410
trigger11 = movecontact = 1


; Parado c/ soco Fraco
[State -1]
type = ChangeState
value = 605
trigger1 = command = x
trigger1 = statetype = A
trigger1 = Vel X = 0
trigger1 = ctrl = 1

; Voadora p/ Frente com soco Forte
[State -1]
type = ChangeState
value = 606
trigger1 = command = x
trigger1 = statetype = A
trigger1 = ctrl = 1

; Esquivar p/ Frente
[State -1]
type = ChangeState
value = 720
trigger1 = command = fwd_roll
trigger1 = statetype != A
trigger1 = ctrl = 1

; Esquivar p/ trs
[State -1]
type = ChangeState
value = 725
trigger1 = command = back_roll
trigger1 = statetype != A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Jump B
[State -1]
type = ChangeState
value = 610
trigger1 = command = b
trigger1 = statetype = A
trigger1 = Vel X = 0
trigger1 = ctrl = 1

; Jump_B2
[State -1]
type = ChangeState
value = 616
trigger1 = command = b
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Jump B1
[State -1]
type = ChangeState
value = 615
trigger1 = command = y
trigger1 = statetype = A
trigger1 = Vel X = 0
trigger1 = ctrl = 1

; Jump_B3
[State -1]
type = ChangeState
value = 617
trigger1 = command = y
trigger1 = statetype = A
trigger1 = ctrl = 1

; Voadora CD
[State -1]
type = ChangeState
value = 618
trigger1 = command = c
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; uppercut-heavy
[State -1]
type = ChangeState
value = 1320
triggerall = command = upper_h
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movehit = 1
trigger3 = stateno = 205
trigger3 = movehit = 1
trigger4 = stateno = 206
trigger4 = movehit = 1
trigger5 = stateno = 207
trigger5 = movehit = 1
trigger6 = stateno = 210
trigger6 = movehit = 1
trigger7 = stateno = 217
trigger7 = movehit = 1
trigger8 = stateno = 218
trigger8 = movehit = 1
trigger9 = stateno = 400
trigger9 = movehit = 1
trigger10 = stateno = 405
trigger10 = movehit = 1
trigger11 = stateno = 410
;trigger11 = movecontact = 1
trigger11 = movehit = 1

;---------------------------------------------------------------------------
; uppercut-heavy
[State -1]
type = ChangeState
value = 1324
triggerall = command = upper_y
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movehit = 1
trigger3 = stateno = 205
trigger3 = movehit = 1
trigger4 = stateno = 206
trigger4 = movehit = 1
trigger5 = stateno = 207
trigger5 = movehit = 1
trigger6 = stateno = 210
trigger6 = movehit = 1
trigger7 = stateno = 217
trigger7 = movehit = 1
trigger8 = stateno = 218
trigger8 = movehit = 1
trigger9 = stateno = 400
trigger9 = movehit = 1
trigger10 = stateno = 405
trigger10 = movehit = 1
trigger11 = stateno = 410
;trigger11 = movecontact = 1
trigger11 = movehit = 1

;---------------------------------------------------------------------------
;Stand_A2
[State -1]
type = ChangeState
value = 206
triggerall = command = frente_a
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 217
trigger6 = movecontact = 1
trigger7 = stateno = 218
trigger7 = movecontact = 1
trigger8 = stateno = 207
trigger8 = movecontact = 1
trigger9 = stateno = 405
trigger9 = movecontact = 1

;---------------------------------------------------------------------------
;Stand_B2
[State -1]
type = ChangeState
value = 216
triggerall = command = frente_b
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 217
trigger6 = movecontact = 1
trigger7 = stateno = 218
trigger7 = movecontact = 1
trigger8 = stateno = 207
trigger8 = movecontact = 1
trigger9 = stateno = 405
trigger9 = movecontact = 1

;Stand_A3
[State -1]
type = ChangeState
value = 207
trigger1 = command = a
trigger1 = p2bodydist x <= 20
trigger1 = statetype = S
trigger1 = ctrl = 1

;Stand_B3
[State -1]
type = ChangeState
value = 217
trigger1 = command = y
trigger1 = p2bodydist x <= 20
trigger1 = statetype = S
trigger1 = ctrl = 1

;Stand_B4
[State -1]
type = ChangeState
value = 218
trigger1 = command = b
trigger1 = p2bodydist x <= 20
trigger1 = statetype = S
trigger1 = ctrl = 1

;===========================================================================
;---------------------------------------------------------------------------
;RunFwd
[State -1]
type = ChangeState
value = 100
trigger1 = command = FF
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;RunBack
[State -1]
type = ChangeState
value = 105
trigger1 = command = BB
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Stand_A
[State -1]
type = ChangeState
value = 200
triggerall = command = a          ;Place name of command here
triggerall = command != holddown  ;Standing moves should have this line
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Stand_A1
[State -1]
type = ChangeState
value = 205
triggerall = command = x          ;Place name of command here
triggerall = command != holddown  ;Standing moves should have this line
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Ombrada
[State -1]
type = ChangeState
value = 208
triggerall = command = c         
triggerall = command != holddown 
trigger1 = statetype = S
trigger1 = ctrl = 1



;---------------------------------------------------------------------------
;Stand_B
[State -1]
type = ChangeState
value = 210
triggerall = command = b
triggerall = command != holddown
trigger1 = statetype = S
trigger1 = ctrl = 1
 ;Uncomment the following if you want to be able to "chain" the attack
 ;from a Stand_A (state 200)
;trigger2 = stateno = 200
;trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent

;---------------------------------------------------------------------------
;Stand_B1
[State -1]
type = ChangeState
value = 215
triggerall = command = y
triggerall = command != holddown
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Crouch_A
[State -1]
type = ChangeState
value = 400
triggerall = command = a
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Crouch_A1
[State -1]
type = ChangeState
value = 405
triggerall = command = x
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Crouch_B
[State -1]
type = ChangeState
value = 410
triggerall = command = b
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Crouch_B1
[State -1]
type = ChangeState
value = 415
triggerall = command = y
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1


;---------------------------------------------------------------------------
;Jump_A
[State -1]
type = ChangeState
value = 600
trigger1 = command = a
trigger1 = statetype = A
trigger1 = ctrl = 1

