; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted


;-| Super Motions |--------------------------------------------------------

[Command]
name = DM_A3
command = ~D, DB, B, DB, D, DF, F, a+b
time = 45

[Command]
name = DM_A
command = ~D, DB, B, DB, D, DF, F, a
time = 45

[Command]
name = DM_A2
command = ~D, DB, B, DB, D, DF, F, b
time = 45

[Command]
name = DM_D3
command = ~D, DB, B, DB, D, DF, F, x+y
time = 45

[Command]
name = DM_D
command = ~D, DB, B, DB, D, DF, F, x
time = 45

[Command]
name = DM_D2
command = ~D, DB, B, DB, D, DF, F, y
time = 45

[Command]
name = DM_E3
command = ~F, B, DB, D, DF, F, x+y
time = 45

[Command]
name = DM_E
command = ~F, B, DB, D, DF, F, x
time = 45

[Command]
name = 2QCB_xy
command = ~D, DB, B, D, DB, B, x+y
time = 45

[Command]
name = 2QCB_y
command = ~D, DB, B, D, DB, B, y
time = 45

[Command]
name = 2QCB_x
command = ~D, DB, B, D, DB, B, x
time = 45

[Command]
name = DM_E2
command = ~F, B, DB, D, DF, F, y
time = 45

[Command]
name = DM_C3
command = ~D, DF, F, D, DF, F, x+y
time = 30

[Command]
name = DM_C1
command = ~D, DF, F, D, DF, F, x
time = 30

[Command]
name = DM_C2
command = ~D, DF, F, D, DF, F, y
time = 30

[Command]
name = 2QCF_a
command = ~D, DF, F, D, DF, F, a
time = 30

[Command]
name = 2QCF_b
command = ~D, DF, F, D, DF, F, b
time = 30

[Command]
name = 2QCF_ab
command = ~D, DF, F, D, DF, F, a+b
time = 30


;-| Special Motions |------------------------------------------------------

[Command]
name = DP_x
command = ~F, D, DF, x 

[Command]
name = DP_y
command = ~F, D, DF, y

[Command]
name = QCF_a
command = ~D, DF, F, a

[Command]
name = QCF_b
command = ~D, DF, F, b

[Command]
name = QCF_x
command = ~D, DF, F, x

[Command]
name = QCF_y
command = ~D, DF, F, y

[Command]
name = QCB_a
command = ~D, DB, B, a

[Command]
name = QCB_b
command = ~D, DB, B, b

[Command]
name = QCB_x
command = ~D, DB, B, x

[Command]
name = QCB_y
command = ~D, DB, B, y

[Command]
name = HCF_a
command = ~B, DB, D, DF, F, a

[Command]
name = HCF_b
command = ~B, DB, D, DF, F, b

;-| Double Tap |-----------------------------------------------------------
[Command]
name = FF       ;Required (do not remove)
command = F, F
time = 10

[Command]
name = BB       ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = recovery ;Required (do not remove)
command = a+b
time = 1

[Command]
name = ab
command = a+b
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = fwd_a
command = /F,a
time = 1

[Command]
name = fwd_b
command = /F,b
time = 1

[Command]
name = fwd_c
command = /F,c
time = 1

[Command]
name = downfwd_a
command = /DF,a
time = 1

[Command]
name = downfwd_b
command = /DF,b
time = 1

[Command]
name = back_a
command = /B,a
time = 1

[Command]
name = back_b
command = /B,b
time = 1

[Command]
name = back_c
command = /B,c
time = 1

[Command]
name = down_a
command = /$D,a
time = 1

[Command]
name = down_b
command = /$D,b
time = 1

[Command]
name = down_c
command = /$D,c
time = 1

[Command]
name = fwd_ab
command = /F, a+b
time = 1

[Command]
name = back_ab
command = /B, a+b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = a
command = a
time = 1

[Command]
name = b
command = b
time = 1

[Command]
name = c
command = c
time = 1

[Command]
name = x
command = x
time = 1

[Command]
name = y
command = y
time = 1

[Command]
name = z
command = z
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = holdfwd  ;Required (do not remove)
command = /$F
time = 1

[Command]
name = holdback ;Required (do not remove)
command = /$B
time = 1

[Command]
name = holdup   ;Required (do not remove)
command = /$U
time = 1

[Command]
name = holddown ;Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
;---------------------------------------------------------------------------
;Death move A3 (QCB HCF +Kick in kof99)
[State -1]
type = ChangeState
value = 3005
triggerall = command = DM_A3
triggerall = power >= 3000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
;trigger2 = hitdefattr = SC, NA, SA
;trigger2 = movecontact = 1
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 400
trigger5 = movecontact = 1
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 213
trigger7 = movecontact = 1
trigger8 = stateno = 211
trigger8 = movecontact = 1
trigger9 = stateno = 201
trigger9 = movecontact = 1
trigger10 = stateno = 203
trigger10= movecontact = 1
trigger11 = stateno = 1020
trigger11= movecontact = 1
trigger12 = stateno = 401
trigger12 = movecontact = 1
trigger13 = stateno = 411
trigger13 = movecontact = 1

;---------------------------------------------------------------------------
;Death move A (QCB HCF +Kick in kof99)
[State -1]
type = ChangeState
value = 3000
triggerall = command = DM_A
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
;trigger2 = hitdefattr = SC, NA, SA
;trigger2 = movecontact = 1
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 400
trigger5 = movecontact = 1
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 213
trigger7 = movecontact = 1
trigger8 = stateno = 211
trigger8 = movecontact = 1
trigger9 = stateno = 201
trigger9 = movecontact = 1
trigger10 = stateno = 203
trigger10= movecontact = 1
trigger11 = stateno = 1020
trigger11= movecontact = 1
trigger12 = stateno = 401
trigger12 = movecontact = 1
trigger13 = stateno = 411
trigger13 = movecontact = 1

;---------------------------------------------------------------------------
;Death move A 2 (QCB HCF +Kick in kof99)
[State -1]
type = ChangeState
value = 3002
triggerall = command = DM_A2
triggerall = power >= 2000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
;trigger2 = hitdefattr = SC, NA, SA
;trigger2 = movecontact = 1
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 400
trigger5 = movecontact = 1
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 213
trigger7 = movecontact = 1
trigger8 = stateno = 211
trigger8 = movecontact = 1
trigger9 = stateno = 201
trigger9 = movecontact = 1
trigger10 = stateno = 203
trigger10= movecontact = 1
trigger11 = stateno = 1020
trigger11= movecontact = 1
trigger12 = stateno = 401
trigger12 = movecontact = 1
trigger13 = stateno = 411
trigger13 = movecontact = 1
;---------------------------------------------------------------------------
;Death move D3 (Super Dragon punch)
[State -1]
type = ChangeState
value = 3420
triggerall = command = DM_D3
triggerall = power >= 3000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
;trigger2 = hitdefattr = SC, NA, SA
;trigger2 = movecontact = 1
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 400
trigger5 = movecontact = 1
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 213
trigger7 = movecontact = 1
trigger8 = stateno = 211
trigger8 = movecontact = 1
trigger9 = stateno = 201
trigger9 = movecontact = 1
trigger10 = stateno = 203
trigger10= movecontact = 1
trigger11 = stateno = 1020
trigger11= movecontact = 1
trigger12 = stateno = 401
trigger12 = movecontact = 1
trigger13 = stateno = 411
trigger13 = movecontact = 1
;---------------------------------------------------------------------------
;Death move D (Super Dragon punch)
[State -1]
type = ChangeState
value = 3400
triggerall = command = DM_D
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
;trigger2 = hitdefattr = SC, NA, SA
;trigger2 = movecontact = 1
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 400
trigger5 = movecontact = 1
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 213
trigger7 = movecontact = 1
trigger8 = stateno = 211
trigger8 = movecontact = 1
trigger9 = stateno = 201
trigger9 = movecontact = 1
trigger10 = stateno = 203
trigger10= movecontact = 1
trigger11 = stateno = 1020
trigger11= movecontact = 1
trigger12 = stateno = 401
trigger12 = movecontact = 1
trigger13 = stateno = 411
trigger13 = movecontact = 1

;---------------------------------------------------------------------------
;Death move D2 (Super Dragon punch)
[State -1]
type = ChangeState
value = 3410
triggerall = command = DM_D2
triggerall = power >= 2000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
;trigger2 = hitdefattr = SC, NA, SA
;trigger2 = movecontact = 1
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 400
trigger5 = movecontact = 1
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 213
trigger7 = movecontact = 1
trigger8 = stateno = 211
trigger8 = movecontact = 1
trigger9 = stateno = 201
trigger9 = movecontact = 1
trigger10 = stateno = 203
trigger10= movecontact = 1
trigger11 = stateno = 1020
trigger11= movecontact = 1
trigger12 = stateno = 401
trigger12 = movecontact = 1
trigger13 = stateno = 411
trigger13 = movecontact = 1
;---------------------------------------------------------------------------
;Death move E3 (Multi projectiles)
[State -1]
type = ChangeState
value = 3520
triggerall = command = DM_E3
triggerall = power >= 3000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 400
trigger5 = movecontact = 1
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 213
trigger7 = movecontact = 1
trigger8 = stateno = 211
trigger8 = movecontact = 1
trigger9 = stateno = 201
trigger9 = movecontact = 1
trigger10 = stateno = 203
trigger10= movecontact = 1
trigger11 = stateno = 1020
trigger11= movecontact = 1
trigger12 = stateno = 401
trigger12 = movecontact = 1
trigger13 = stateno = 411
trigger13 = movecontact = 1

;---------------------------------------------------------------------------
;Death move E (Multi projectiles)
[State -1]
type = ChangeState
value = 3500
triggerall = command = DM_E
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 400
trigger5 = movecontact = 1
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 213
trigger7 = movecontact = 1
trigger8 = stateno = 211
trigger8 = movecontact = 1
trigger9 = stateno = 201
trigger9 = movecontact = 1
trigger10 = stateno = 203
trigger10= movecontact = 1
trigger11 = stateno = 1020
trigger11= movecontact = 1
trigger12 = stateno = 401
trigger12 = movecontact = 1
trigger13 = stateno = 411
trigger13 = movecontact = 1

;---------------------------------------------------------------------------
;Death move E2 (Multi projectiles)
[State -1]
type = ChangeState
value = 3510
triggerall = command = DM_E2
triggerall = power >= 2000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 400
trigger5 = movecontact = 1
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 213
trigger7 = movecontact = 1
trigger8 = stateno = 211
trigger8 = movecontact = 1
trigger9 = stateno = 201
trigger9 = movecontact = 1
trigger10 = stateno = 203
trigger10= movecontact = 1
trigger11 = stateno = 1020
trigger11= movecontact = 1
trigger12 = stateno = 401
trigger12 = movecontact = 1
trigger13 = stateno = 411
trigger13 = movecontact = 1

;---------------------------------------------------------------------------
;Super Death move C3
[State -1]
type = ChangeState
value = 3302
triggerall = command = DM_C3
triggerall = power >= 3000
;triggerall = life <= 550
trigger1 = statetype != A
trigger1 = ctrl = 1
;trigger2 = statetype != A
;trigger2 = hitdefattr = SC, NA, SA
;trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 213
trigger6 = movecontact = 1
trigger7 = stateno = 211
trigger7 = movecontact = 1
trigger8 = stateno = 201
trigger8 = movecontact = 1
trigger9 = stateno = 203
trigger9 = movecontact = 1
trigger10 = stateno = 1010
trigger10= movecontact = 1
trigger11 = stateno = 1011
trigger11 = movecontact = 1
trigger12 = stateno = 401
trigger12 = movecontact = 1
trigger13 = stateno = 411
trigger13 = movecontact = 1

;---------------------------------------------------------------------------
;Super Death move C2
[State -1]
type = ChangeState
value = 3301
triggerall = command = DM_C2
triggerall = power >= 2000
;triggerall = life <= 550
trigger1 = statetype != A
trigger1 = ctrl = 1
;trigger2 = statetype != A
;trigger2 = hitdefattr = SC, NA, SA
;trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 213
trigger6 = movecontact = 1
trigger7 = stateno = 211
trigger7 = movecontact = 1
trigger8 = stateno = 201
trigger8 = movecontact = 1
trigger9 = stateno = 203
trigger9 = movecontact = 1
trigger10 = stateno = 1010
trigger10= movecontact = 1
trigger11 = stateno = 1011
trigger11 = movecontact = 1
trigger12 = stateno = 401
trigger12 = movecontact = 1
trigger13 = stateno = 411
trigger13 = movecontact = 1

;---------------------------------------------------------------------------
;Death move C1
[State -1]
type = ChangeState
value = 3300
triggerall = command = DM_C1
triggerall = power >= 1000
;triggerall = life > 550
trigger1 = statetype != A
trigger1 = ctrl = 1
;trigger2 = statetype != A
;trigger2 = hitdefattr = SC, NA, SA
;trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 213
trigger6 = movecontact = 1
trigger7 = stateno = 211
trigger7 = movecontact = 1
trigger8 = stateno = 201
trigger8 = movecontact = 1
trigger9 = stateno = 203
trigger9 = movecontact = 1
trigger10 = stateno = 1010
trigger10= movecontact = 1
trigger11 = stateno = 1011
trigger11 = movecontact = 1
trigger12 = stateno = 401
trigger12 = movecontact = 1
trigger13 = stateno = 411
trigger13 = movecontact = 1

;===========================================
;Superwaza AB
[State -1]
type = ChangeState
value = 3102
triggerall = command = 2QCF_ab
triggerall = power >= 3000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA
trigger2 = movecontact = 1
;===========================================
;Superwaza A
[State -1]
type = ChangeState
value = 3100
triggerall = command = 2QCF_a
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA
trigger2 = movecontact = 1

;===========================================
;Superwaza B
[State -1]
type = ChangeState
value = 3101
triggerall = command = 2QCF_b
triggerall = power >= 2000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA
trigger2 = movecontact = 1

;===========================================================================
;---------------------------------------------------------------------------
;SpecialA (HCF+kick in kof99)
[State -1]
type = ChangeState
value = 1000
triggerall = command = HCF_b
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 213
trigger6 = movecontact = 1
trigger7 = stateno = 211
trigger7 = movecontact = 1
trigger8 = stateno = 201
trigger8 = movecontact = 1
trigger9 = stateno = 203
trigger9 = movecontact = 1
trigger10 = stateno = 401
trigger10 = movecontact = 1
trigger11 = stateno = 411
trigger11 = movecontact = 1

;---------------------------------------------------------------------------
;SpecialA 2 (HCF+kick in kof99)
[State -1]
type = ChangeState
value = 1000
triggerall = command = HCF_a
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 213
trigger6 = movecontact = 1
trigger7 = stateno = 211
trigger7 = movecontact = 1
trigger8 = stateno = 201
trigger8 = movecontact = 1
trigger9 = stateno = 203
trigger9 = movecontact = 1
trigger10 = stateno = 401
trigger10 = movecontact = 1
trigger11 = stateno = 411
trigger11 = movecontact = 1

;---------------------------------------------------------------------------
;Dragon punch X
[State -1]
type = ChangeState
value = 1030
triggerall = command = DP_x
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 213
trigger6 = movecontact = 1
trigger7 = stateno = 211
trigger7 = movecontact = 1
trigger8 = stateno = 201
trigger8 = movecontact = 1
trigger9 = stateno = 203
trigger9 = movecontact = 1
trigger10 = stateno = 401
trigger10 = movecontact = 1
trigger11 = stateno = 411
trigger11 = movecontact = 1
trigger12 = stateno = 1040
trigger12 = movecontact = 1
trigger12 = time >= 15

;---------------------------------------------------------------------------
;Dragon punch Y
[State -1]
type = ChangeState
value = 1031
triggerall = command = DP_y
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 213
trigger6 = movecontact = 1
trigger7 = stateno = 211
trigger7 = movecontact = 1
trigger8 = stateno = 201
trigger8 = movecontact = 1
trigger9 = stateno = 203
trigger9 = movecontact = 1
trigger10 = stateno = 401
trigger10 = movecontact = 1
trigger11 = stateno = 411
trigger11 = movecontact = 1
trigger12 = stateno = 1040
trigger12 = movecontact = 1
trigger12 = time >= 15

;---------------------------------------------------------------------------
;Special D
[State -1]
type = ChangeState
value = 1040
triggerall = command = QCB_a
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 213
trigger6 = movecontact = 1
trigger7 = stateno = 211
trigger7 = movecontact = 1
trigger8 = stateno = 201
trigger8 = movecontact = 1
trigger9 = stateno = 203
trigger9 = movecontact = 1
trigger10 = stateno = 401
trigger10 = movecontact = 1
trigger11 = stateno = 411
trigger11 = movecontact = 1

;---------------------------------------------------------------------------
;Special D
[State -1]
type = ChangeState
value = 1040
triggerall = command = QCB_b
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 213
trigger6 = movecontact = 1
trigger7 = stateno = 211
trigger7 = movecontact = 1
trigger8 = stateno = 201
trigger8 = movecontact = 1
trigger9 = stateno = 203
trigger9 = movecontact = 1
trigger10 = stateno = 401
trigger10 = movecontact = 1
trigger11 = stateno = 411
trigger11 = movecontact = 1

;---------------------------------------------------------------------------
;KashoSen
[State -1]
type = ChangeState
value = 1010
triggerall = command = QCF_x
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 213
trigger6 = movecontact = 1
trigger7 = stateno = 211
trigger7 = movecontact = 1
trigger8 = stateno = 201
trigger8 = movecontact = 1
trigger9 = stateno = 203
trigger9 = movecontact = 1
trigger10 = stateno = 401
trigger10 = movecontact = 1
trigger11 = stateno = 411
trigger11 = movecontact = 1

;---------------------------------------------------------------------------
;KashoSen2
[State -1]
type = ChangeState
value = 1011
triggerall = command = QCF_y
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 213
trigger6 = movecontact = 1
trigger7 = stateno = 211
trigger7 = movecontact = 1
trigger8 = stateno = 201
trigger8 = movecontact = 1
trigger9 = stateno = 203
trigger9 = movecontact = 1
trigger10 = stateno = 401
trigger10 = movecontact = 1
trigger11 = stateno = 411
trigger11 = movecontact = 1

;---------------------------------------------------------------------------
;SpecialB (QCB+Punch in kof99)
[State -1]
type = ChangeState
value = 1020
triggerall = command = QCB_y
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 213
trigger6 = movecontact = 1
trigger7 = stateno = 211
trigger7 = movecontact = 1
trigger8 = stateno = 201
trigger8 = movecontact = 1
trigger9 = stateno = 203
trigger9 = movecontact = 1
trigger10 = stateno = 401
trigger10 = movecontact = 1
trigger11 = stateno = 411
trigger11 = movecontact = 1
trigger12 = stateno = 1040
trigger12 = movecontact = 1
trigger12 = time >= 15

;---------------------------------------------------------------------------
;SpecialB (QCB+Punch in kof99)
[State -1]
type = ChangeState
value = 1020
triggerall = command = QCB_x
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 213
trigger6 = movecontact = 1
trigger7 = stateno = 211
trigger7 = movecontact = 1
trigger8 = stateno = 201
trigger8 = movecontact = 1
trigger9 = stateno = 203
trigger9 = movecontact = 1
trigger10 = stateno = 401
trigger10 = movecontact = 1
trigger11 = stateno = 411
trigger11 = movecontact = 1
trigger12 = stateno = 1040
trigger12 = movecontact = 1
trigger12 = time >= 15
;---------------------------------------------------------------------------
;Death move F3 (2QCB+Punch in the air)
[State -1]
type = ChangeState
value = 3605
triggerall = command = 2QCB_xy
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600
trigger2 = movecontact = 1
trigger3 = stateno = 601
trigger3 = movecontact = 1
trigger4 = stateno = 610
trigger4 = movecontact = 1
trigger5 = stateno = 611
trigger6 = stateno = 1030
trigger6 = movecontact = 1
trigger6 = time >= 15
;---------------------------------------------------------------------------
;Death move F (2QCB+Punch in the air)
[State -1]
type = ChangeState
value = 3600
triggerall = command = 2QCB_x
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600
trigger2 = movecontact = 1
trigger3 = stateno = 601
trigger3 = movecontact = 1
trigger4 = stateno = 610
trigger4 = movecontact = 1
trigger5 = stateno = 611
trigger6 = stateno = 1030
trigger6 = movecontact = 1
trigger6 = time >= 15

;---------------------------------------------------------------------------
;Death move F2 (2QCB+Punch in the air)
[State -1]
type = ChangeState
value = 3603
triggerall = command = 2QCB_y
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600
trigger2 = movecontact = 1
trigger3 = stateno = 601
trigger3 = movecontact = 1
trigger4 = stateno = 610
trigger4 = movecontact = 1
trigger5 = stateno = 611
trigger6 = stateno = 1030
trigger6 = movecontact = 1
trigger6 = time >= 15

;---------------------------------------------------------------------------
;SpecialE (QCB+Punch in the air in kof99)
[State -1]
type = ChangeState
value = 1052
triggerall = command = QCB_x
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600
trigger2 = movecontact = 1
trigger3 = stateno = 601
trigger3 = movecontact = 1
trigger4 = stateno = 610
trigger4 = movecontact = 1
trigger5 = stateno = 611
trigger6 = stateno = 1030
trigger6 = movecontact = 1
trigger6 = time >= 15
;---------------------------------------------------------------------------
;SpecialE (QCB+Punch in the air in kof99)
[State -1]
type = ChangeState
value = 1053
triggerall = command = QCB_y
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600
trigger2 = movecontact = 1
trigger3 = stateno = 601
trigger3 = movecontact = 1
trigger4 = stateno = 610
trigger4 = movecontact = 1
trigger5 = stateno = 611
trigger6 = stateno = 1030
trigger6 = movecontact = 1
trigger6 = time >= 15

;===========================================================================
;---------------------------------------------------------------------------
;RunFwd
[State -1]
type = ChangeState
value = 100
trigger1 = command = FF
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;RunBack
[State -1]
type = ChangeState
value = 105
trigger1 = command = BB
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Stand_Throw
[State -1]
type = null;ChangeState
value = 900
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = command = fwd_ab  ;Command
trigger2 = command = back_ab ;Command
trigger3 = command = fwd_b   ;Near, p2 stand
trigger3 = stateno != 100    ;Not running
trigger3 = p2bodydist X < 3
trigger3 = p2statetype = S
trigger3 = p2movetype != H
trigger4 = command = fwd_b   ;Near, p2 crouch
trigger4 = stateno != 100    ;Not running
trigger4 = p2bodydist X < 3
trigger4 = p2statetype = C
trigger4 = p2movetype != H
trigger5 = command = back_b  ;Near, p2 stand
trigger5 = p2bodydist X < 5
trigger5 = p2statetype = S
trigger5 = p2movetype != H
trigger6 = command = back_b  ;Near, p2 crouch
trigger6 = p2bodydist X < 5
trigger6 = p2statetype = C
trigger6 = p2movetype != H

;---------------------------------------------------------------------------
;Air_Throw1
[State -1]
type = null;ChangeState
value = 950
triggerall = statetype = A
triggerall = ctrl = 1
trigger1 = command = fwd_ab
trigger2 = command = back_ab
;---------------------------
;Air_Throw1 (second set of commands)
[State -1]
type = null;ChangeState
value = 950
triggerall = statetype = A
triggerall = ctrl = 1
triggerall = p2bodydist X < 9
triggerall = p2bodydist Y > -22
triggerall = p2bodydist Y < 22
triggerall = p2statetype = A
triggerall = p2movetype != H
trigger1 = command = fwd_b
trigger2 = command = back_b


;===========================================================================
;---------------------------------------------------------------------------
;Stand_x
[State -1]
type = ChangeState
value = 200
triggerall = command = x
triggerall = command != holddown
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 210
trigger2 = movecontact = 1
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 611
trigger4 = movecontact = 1
trigger4 = pos y >= 0
;trigger4 = stateno = 200
;trigger4 = time > 7

;---------------------------------------------------------------------------
;Stand_y
[State -1]
type = ChangeState
value = 201
triggerall = command = y
triggerall = command != holddown
triggerall = P2bodydist X > 32
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 210
trigger2 = movecontact = 1
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 611
trigger4 = movecontact = 1
trigger4 = pos y >= 0

;---------------------------------------------------------------------------
;Stand_y close
[State -1]
type = ChangeState
value = 203
triggerall = command = y
triggerall = command != holddown
triggerall = P2bodydist X <= 32
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 210
trigger2 = movecontact = 1
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 611
trigger4 = movecontact = 1
trigger4 = pos y >= 0

;---------------------------------------------------------------------------
;Stand_a
[State -1]
type = ChangeState
value = 210
triggerall = command = a
triggerall = command != holddown
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 611
trigger4 = movecontact = 1
trigger4 = pos y >= 0

;---------------------------------------------------------------------------
;Stand_B
[State -1]
type = ChangeState
value = 211
triggerall = command = b
triggerall = command != holddown
triggerall = P2bodydist X > 32
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 611
trigger4 = movecontact = 1
trigger4 = pos y >= 0

;---------------------------------------------------------------------------
;Stand_B close
[State -1]
type = ChangeState
value = 213
triggerall = command = b
triggerall = command != holddown
triggerall = P2bodydist X <= 32
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 611
trigger4 = movecontact = 1
trigger4 = pos y >= 0
;---------------------------------------------------------------------------
;Crouch_a
[State -1]
type = ChangeState
value = 410
triggerall = command = a
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1


;---------------------------------------------------------------------------
;Crouch_x
[State -1]
type = ChangeState
value = 400
triggerall = command = x
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Crouch_B
[State -1]
type = ChangeState
value = 411
triggerall = command = b
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 400 ;crouch_a
trigger2 = movecontact = 1
trigger3 = stateno = 410 ;crouch_x
trigger3 = movecontact = 1
trigger4 = stateno = 200 ;stand_a
trigger4 = movecontact = 1
trigger5 = stateno = 210 ;stand_x
trigger5 = movecontact = 1

;---------------------------------------------------------------------------
;Crouch_y
[State -1]
type = ChangeState
value = 401
triggerall = command = y
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 400 ;crouch_a
trigger2 = movecontact = 1
trigger3 = stateno = 410 ;crouch_x
trigger3 = movecontact = 1
trigger4 = stateno = 200 ;stand_a
trigger4 = movecontact = 1
trigger5 = stateno = 210 ;stand_x
trigger5 = movecontact = 1
;---------------------------------------------------------------------------
;Jump_A
[State -1]
type = ChangeState
value = 610
trigger1 = command = a
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = a   ;-------
trigger2 = stateno = 600 ;jump_a
trigger2 = statetime >= 6

;---------------------------------------------------------------------------
;Jump_X
[State -1]
type = ChangeState
value = 600
trigger1 = command = x
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = a   ;-------
trigger2 = stateno = 600 ;jump_a
trigger2 = statetime >= 6

;---------------------------------------------------------------------------
;Jump_B forward
[State -1]
type = ChangeState
value = 611
triggerall = vel X != 0
trigger1 = command = b
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = b   ;-------
trigger2 = stateno = 600 ;jump_a
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;Jump_B Neutral
[State -1]
type = ChangeState
value = 613
triggerall = vel X = 0
trigger1 = command = b
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = b   ;-------
trigger2 = stateno = 600 ;jump_a
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;Jump_y
[State -1]
type = ChangeState
value = 601
trigger1 = command = y
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = y   ;-------
trigger2 = stateno = 600 ;jump_a
trigger2 = movecontact = 1
