; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands are given below. Delete, add, or modify as you wish.

;-| Super Motions |--------------------------------------------------------
; MYRACLE VOICE
[Command]
name = harahara1
command = ~D, D,  a+b
time = 15

[Command]
name = harahara2
command = ~D, D,  x+y
time = 15

; BUNBUN TYPHOON - rotate 360 + XY
[Command]
name = 360_1
command = ~F, U, B, D, x+y
time = 20

[Command]
name = 360_2
command = ~U, B, D, F, x+y
time = 20

[Command]
name = 360_3
command = ~B, D, F, U, x+y
time = 20

[Command]
name = 360_4
command = ~D, F, U, B, x+y
time = 20

; ES GURUGURU PUNCH
[Command]
name = QCF_xy
command = ~D, DF, F, x+y

; ES BODY PRESS
[Command]
name = QCF_ab
command = ~D, DB, B, a+b

; ES BUNBUN COPTER
[Command]
name = uppercut_xy
command = ~F, D, DF, x+y

;-| Special Motions |------------------------------------------------------
;-----------------
; HCB
[Command]
name = HCB_b
command = ~F, D, B, b

;-----------------
; QCF
[Command]
name = QCF_a
command = ~D, DF, F, a

[Command]
name = QCF_b
command = ~D, DF, F, b

[Command]
name = QCF_c
command = ~D, DF, F, c

[Command]
name = QCF_x
command = ~D, DF, F, x

[Command]
name = QCF_y
command = ~D, DF, F, y

[Command]
name = QCF_z
command = ~D, DF, F, z

;-----------------
; QCB
[Command]
name = QCB_a
command = ~D, DB, B, a

[Command]
name = QCB_b
command = ~D, DB, B, b

[Command]
name = QCB_c
command = ~D, DB, B, c

[Command]
name = QCB_x
command = ~D, DB, B, x

[Command]
name = QCB_y
command = ~D, DB, B, y

[Command]
name = QCB_z
command = ~D, DB, B, z

;-----------------
; Uppercut
[Command]
name = uppercut_a
command = ~F, D, DF, a

[Command]
name = uppercut_b
command = ~F, D, DF, b

[Command]
name = uppercut_c
command = ~F, D, DF, c

[Command]
name = uppercut_x
command = ~F, D, DF, x

[Command]
name = uppercut_y
command = ~F, D, DF, y

[Command]
name = uppercut_z
command = ~F, D, DF, z


;--------------------
;Charge_Down_up
[Command]
name = chargedownup_a
command = ~60$D, U, a
time = 10

[Command]
name = chargedownup_b
command = ~60$D, U, b
time = 10

[Command]
name = chargedownup_c
command = ~60$D, U, c
time = 10

[Command]
name = chargedownup_x
command = ~60$D, U, x
time = 10

[Command]
name = chargedownup_y
command = ~60$D, U, y
time = 10

[Command]
name = chargedownup_z
command = ~60$D, U, z
time = 10

;--------------------
;Charge_Back_fwd
[Command]
name = chargebackfwd_a
command = ~60$B, F, a
time = 10

[Command]
name = chargebackfwd_b
command = ~60$B, F, b
time = 10

[Command]
name = chargedownup_c
command = ~60$D, U, c
time = 10

[Command]
name = chargedownup_x
command = ~60$D, U, x
time = 10

[Command]
name = chargedownup_y
command = ~60$D, U, y
time = 10

[Command]
name = chargedownup_z
command = ~60$D, U, z
time = 10



;-| Double Tap |-----------------------------------------------------------
[Command]
name = FF       ;Required (do not remove)
command = F, F
time = 10

[Command]
name = BB       ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = recovery ;Required (do not remove)
command = a+b
time = 1

[Command]
name = ab
command = a+b
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = fwd_a
command = /F,a
time = 1

[Command]
name = fwd_b
command = /F,b
time = 1

[Command]
name = fwd_c
command = /F,c
time = 1

[Command]
name = fwd_x
command = /F,x
time = 1

[Command]
name = fwd_y
command = /F,y
time = 1

[Command]
name = fwd_z
command = /F,z
time = 1

[Command]
name = back_a
command = /B,a
time = 1

[Command]
name = back_b
command = /B,b
time = 1

[Command]
name = back_c
command = /B,c
time = 1

[Command]
name = back_y
command = /B,y
time = 1

[Command]
name = down_a
command = /$D,a
time = 1

[Command]
name = down_b
command = /$D,b
time = 1

[Command]
name = down_c
command = /$D,c
time = 1

[Command]
name = fwd_ab
command = /F, a+b
time = 1

[Command]
name = back_ab
command = /B, a+b
time = 1

;-| 2 Buttons |---------------------------------------------------------
[Command]
name = ax
command = a+x
time = 1

[Command]
name = ay
command = a+y
time = 1

[Command]
name = bx
command = b+x
time = 1

[Command]
name = by
command = b+y
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = a
command = a
time = 1

[Command]
name = b
command = b
time = 1

[Command]
name = c
command = c
time = 1

[Command]
name = x
command = x
time = 1

[Command]
name = y
command = y
time = 1

[Command]
name = z
command = z
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = holdfwd  ;Required (do not remove)
command = /$F
time = 1

[Command]
name = fwd  ;Required (do not remove)
command = F
time = 1

[Command]
name = holdback ;Required (do not remove)
command = /$B
time = 1

[Command]
name = holdup   ;Required (do not remove)
command = /$U
time = 1

[Command]
name = holddown ;Required (do not remove)
command = /$D
time = 1

[Command]
name = holdup  
command = /$U
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in. 


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
;BUNBUN TYPHOON - 360 + XY
[State -1]
type = ChangeState
value = 4600
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = power >= 1000
trigger1 = command = 360_1
trigger2 = command = 360_2
trigger3 = command = 360_3
trigger4 = command = 360_4

;---------------------------------------------------------------------------
;ES BUNBUN COPTER - F,D,D/F + XY
[State -1]
type = ChangeState
value = 3200
triggerall = command = uppercut_xy
triggerall = power >= 1000
;trigger1 = statetype = S
trigger1 = ctrl = 1
;trigger2 = stateno = 230
;trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;ES BODY PRESS - QCF + AB
[State -1]
type = ChangeState
value = 3100
triggerall = command = QCF_ab
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
;trigger2 = stateno = 230
;trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;ES GURUGURU PUNCH (STRONG) - QCF + XY
[State -1]
type = ChangeState
value = 3000
triggerall = command = QCF_xy
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
;trigger2 = stateno = 230
;trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;MAURU BINTA - HCB + B
[State -1]
type = ChangeState
value = 1300
triggerall = command = HCB_b
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = p2bodydist X <= 15
triggerall = p2movetype != H
trigger1 = p2statetype = S
trigger2 = p2statetype = C

;---------------------------------------------------------------------------
;GURUGURU PUNCH (WEAK) - QCF + X
[State -1]
type = ChangeState
value = 1000
triggerall = command = QCF_x
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 230
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;GURUGURU PUNCH (STRONG) - QCF + Y
[State -1]
type = ChangeState
value = 1010
triggerall = command = QCF_y
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 230
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;BODY PRESS (WEAK) - QCB + A
[State -1]
type = ChangeState
value = 1100
triggerall = command = QCB_a
trigger1 = statetype = S
trigger1 = ctrl = 1
;trigger2 = stateno = 230
;trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;BODY PRESS (STRONG) - QCB + B
[State -1]
type = ChangeState
value = 1110
triggerall = command = QCB_b
trigger1 = statetype = S
trigger1 = ctrl = 1
;trigger2 = stateno = 230
;trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;BUN BUN COPTER (WEAK) - F,D,F/D + X
[State -1]
type = ChangeState
value = 1200
triggerall = command = uppercut_x
;trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;BUN BUN COPTER (STRONG) - F,D,F/D + Y
[State -1]
type = ChangeState
value = 1210
triggerall = command = uppercut_y
;trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;MIRACLE VOICE - D, D + AB/XY
[State -1]
type = ChangeState
value = 4500
triggerall = ctrl = 1
triggerall = NumProjID4500 = 0
triggerall = power >= 2000
trigger1 = command = harahara1
trigger1 = statetype = S
trigger2 = command = harahara2
trigger2 = statetype = S
trigger3 = command = harahara1
trigger3 = statetype = C
trigger4 = command = harahara2
trigger4 = statetype = C

;---------------------------------------------------------------------------
;Throw
[State -1]
type = ChangeState
value = 250
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = p2bodydist X < 5
triggerall = p2movetype != H
trigger1 = command = fwd_y
trigger1 = p2statetype = S
trigger2 = command = fwd_y
trigger2 = p2statetype = C
trigger3 = command = back_y
trigger3 = p2statetype = S
trigger4 = command = back_y
trigger4 = p2statetype = C

;---------------------------------------------------------------------------
;Air Throw
[State -1]
type = ChangeState
value = 270
triggerall = statetype = A
triggerall = ctrl = 1
triggerall = p2bodydist X < 9
triggerall = p2bodydist Y > -22
triggerall = p2bodydist Y < 22
triggerall = p2movetype != H
triggerall = p2statetype = A
trigger1 = command = fwd_y
trigger2 = command = back_y

;---------------------------------------------------------------------------
; ** DOUBLE CLAW - Any punch + Any kick  ** 
[State -1]
type = ChangeState
value = 700
triggerall = command != holddown
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = command = ax
trigger2 = command = bx
trigger3 = command = ay
trigger4 = command = by

;---------------------------------------------------------------------------
;WAKUWAKU UPPER - Fwd + Y
[State -1]
type = ChangeState
value = 600
triggerall = command = fwd_y
triggerall = command != holddown
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;RunFwd
[State -1]
type = ChangeState
value = 100
trigger1 = command = FF
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;RunBack
[State -1]
type = ChangeState
value = 105
trigger1 = command = BB
trigger1 = statetype = S
trigger1 = ctrl = 1

;===========================================================================
;---------------------------------------------------------------------------
;Stand_X - Weak punch
[State -1]
type = ChangeState
value = 200
triggerall = command = x          ;Place name of command here
triggerall = command != holddown  ;Standing moves should have this line
 ;The following is true if Player is in stand state, and has control
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Stand_Y - Strong punch
[State -1]
type = ChangeState
value = 210
triggerall = command = y
triggerall = command != holddown
trigger1 = statetype = S
trigger1 = ctrl = 1
 ;Uncomment the following if you want to be able to "chain" the attack
 ;from a Stand_A (state 200)
trigger2 = stateno = 200
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 220
trigger3 = movecontact = 1

;---------------------------------------------------------------------------
;Stand_A - Weak kick
[State -1]
type = ChangeState
value = 220
triggerall = command = a          ;Place name of command here
triggerall = command != holddown  ;Standing moves should have this line
 ;The following is true if Player is in stand state, and has control
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;Stand_B - Strong kick
[State -1]
type = ChangeState
value = 230
triggerall = command = b          ;Place name of command here
triggerall = command != holddown  ;Standing moves should have this line
 ;The following is true if Player is in stand state, and has control
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 220
trigger3 = movecontact = 1

;---------------------------------------------------------------------------
;Crouch_X - Weak punch
[State -1]
type = ChangeState
value = 400
triggerall = command = x
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Crouch_Y - Strong punch
[State -1]
type = ChangeState
value = 410
triggerall = command = y
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Crouch_A - Weak kick
[State -1]
type = ChangeState
value = 420
triggerall = command = a
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Crouch_B - Strong kick
[State -1]
type = ChangeState
value = 430
triggerall = command = b
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jump_X
[State -1]
type = ChangeState
value = 500
trigger1 = command = x
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jump_Y (forward/backwards)
[State -1]
type = ChangeState
value = 510
trigger1 = command = y
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger1 = Vel X != 0

;---------------------------------------------------------------------------
;Jump_Y (up)
[State -1]
type = ChangeState
value = 515
trigger1 = command = y
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger1 = Vel X = 0

;---------------------------------------------------------------------------
;Jump_A (forward/backwards)
[State -1]
type = ChangeState
value = 520
trigger1 = command = a
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger1 = Vel X != 0

;---------------------------------------------------------------------------
;Jump_A (up)
[State -1]
type = ChangeState
value = 525
trigger1 = command = a
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger1 = Vel X = 0

;---------------------------------------------------------------------------
;Jump_B
[State -1]
type = ChangeState
value = 530
trigger1 = command = b
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Getting Up Counterattack
[State -1]
type = ChangeState
value = 300
trigger1 = command = holdup
trigger1 = stateno = 5120
trigger1 = Time = 1

;---------------------------------------------------------------------------
;Getting Up Recovery Roll Forward
[State -1]
type = ChangeState
value = 800
trigger1 = command = holdfwd
trigger1 = stateno = 5120
trigger1 = Time = 1

;---------------------------------------------------------------------------
;Getting Up Recovery Roll Backwards
[State -1]
type = ChangeState
value = 810
trigger1 = command = holdback
trigger1 = stateno = 5120
trigger1 = Time = 1

;---------------------------------------------------------------------------

