; The CMD file written by Carlos-Z 1999-2000.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simuleous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands are given below. Delete, add, or modify as you wish.

;-| Super Motions |--------------------------------------------------------
[Command]
name = Haosoboken_a
command = ~F, B, D, F, a
time = 35

[Command]
name = Haosoboken_b
command = ~F, B, D, F, x
time = 35

[Command]
name = koku
command = ~D, F, D, B, a
time = 35

[Command]
name = koku
command = ~D, F, D, B, x
time = 35

[Command]
name = Mue
command = ~D, F, D, F, b
time = 35

[Command]
name = Mue
command = ~D, F, D, F, y
time = 35

;-| Special Motions |------------------------------------------------------
;-----------------
[Command]
name = Kouken
command = ~D, DF, F, a
time = 35

[Command]
name = iuing
command = ~D, DF, F, x
time = 35

[Command]
name = Hien_94
command = ~D, DB, B, b
time = 35

[Command]
name = HiensuShuppukiaku_98
command = ~D, DB, B, y
time = 35

; Uppercut
[Command]
name = Ryuga_a
command = ~D, F, D, a
time = 35

; Uppercut
[Command]
name = Ryuga_b
command = ~D, F, D, x
time = 35

[Command]
name = Ryuzan_a
command = ~D, F, D, b
time = 35

[Command]
name = Ryuzan_b
command = ~D, F, D, y
time = 35

[Command]
name = Engi_a
command = ~F, B, F, b
time = 35

[Command]
name = Engi_b
command = ~F, B, F, y
time = 35

[Command]
name = hk
command = ~D, B, b
time = 35

[Command]
name = hk
command = ~D, B, y
time = 35

;-----------------

[Command]
name = QCB_z
command = ~D, DB, B, z

;-----------------
[Command]
name = uppercut_b
command = ~F, D, DF, b

[Command]
name = uppercut_c
command = ~F, D, DF, c

[Command]
name = uppercut_x
command = ~F, D, DF, x

[Command]
name = uppercut_y
command = ~F, D, DF, y

[Command]
name = uppercut_z
command = ~F, D, DF, z


;--------------------
;Charge_Down_up
[Command]
name = chargedownup_a
command = ~60$D, U, a
time = 10

[Command]
name = chargedownup_b
command = ~60$D, U, b
time = 10

[Command]
name = chargedownup_c
command = ~60$D, U, c
time = 10

[Command]
name = chargedownup_x
command = ~60$D, U, x
time = 10

[Command]
name = chargedownup_y
command = ~60$D, U, y
time = 10

[Command]
name = chargedownup_z
command = ~60$D, U, z
time = 10

;--------------------
;Charge_Back_fwd
[Command]
name = chargebackfwd_a
command = ~60$B, F, a
time = 10

[Command]
name = chargebackfwd_b
command = ~60$B, F, b
time = 10

[Command]
name = chargedownup_c
command = ~60$D, U, c
time = 10

[Command]
name = chargedownup_x
command = ~60$D, U, x
time = 10

[Command]
name = chargedownup_y
command = ~60$D, U, y
time = 10

[Command]
name = chargedownup_z
command = ~60$D, U, z
time = 10



;-| Double Tap |-----------------------------------------------------------
[Command]
name = FF       ;Required (do not remove)
command = F, F
time = 10

[Command]
name = BB       ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = recovery ;Required (do not remove)
command = a+b
time = 1

[Command]
name = ab
command = a+b
time = 1

[Command]
name = xy
command = x+y
time = 1

;--------------------------------
;Roll
;--------------------------------
[Command]
name = fwd_z
command = /F,z
time = 1

[Command]
name = DF_z
command = /DF,z
time = 1

[Command]
name = back_z
command = /B,z
time = 1

[Command]
name = DB_z
command = /DB,z
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = fwd_a
command = /F,a
time = 1

[Command]
name = fwd_b
command = /F,b
time = 1

[Command]
name = fwd_c
command = /F,c
time = 1

[Command]
name = fwd_x
command = /F,x
time = 1

[Command]
name = fwd_y
command = /F,y
time = 1

[Command]
name = fwd_z
command = /F,z
time = 1

[Command]
name = back_a
command = /B,a
time = 1

[Command]
name = back_b
command = /B,b
time = 1

[Command]
name = back_c
command = /B,c
time = 1

[Command]
name = down_a
command = /$D,a
time = 1

[Command]
name = down_b
command = /$D,b
time = 1

[Command]
name = down_c
command = /$D,c
time = 1

[Command]
name = fwd_ab
command = /F, a+b
time = 1

[Command]
name = back_ab
command = /B, a+b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = a
command = a
time = 1

[Command]
name = b
command = b
time = 1

[Command]
name = c
command = c
time = 1

[Command]
name = x
command = x
time = 1

[Command]
name = y
command = y
time = 1

[Command]
name = z
command = z
time = 1

[Command]
name = s
command = s
time = 1

[Command]
name = hold_a
command = /$a
time = 1

[Command]
name = hold_x
command = /$x
time = 1
;-| Hold Dir |--------------------------------------------------------------
[Command]
name = holdfwd  ;Required (do not remove)
command = /$F
time = 1

[Command]
name = holdback ;Required (do not remove)
command = /$B
time = 1

[Command]
name = holdup   ;Required (do not remove)
command = /$U
time = 1

[Command]
name = holddown ;Required (do not remove)
command = /$D
time = 1


;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in. 
; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
;Maximun Kokurengui Oki 
[State -1]
type = ChangeState
value = 3405
triggerall = command = koku
triggerall = power = 3000 ;Level 2
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 202
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 231
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 235
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger9 = movecontact = 1
trigger10 = stateno = 241
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 430
trigger13 = movecontact = 1
trigger14 = stateno = 320
trigger14 = movecontact = 1
;---------------------------------------------------------------------------
;Kokurengiu Oki
[State -1]
type = ChangeState
value = 3400
triggerall = command = koku
triggerall = power >= 1000 ;Level 1
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 202
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 231
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 235
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger9 = movecontact = 1
trigger10 = stateno = 241
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 430
trigger13 = movecontact = 1
trigger14 = stateno = 320
trigger14 = movecontact = 1
;---------------------------------------------------------------------------
;Haosoboken
[State -1]
type = ChangeState
value = 3006
triggerall = command = Haosoboken_a
triggerall = power >= 2000 ;Level 2
trigger1 = statetype != A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Haosoboken
[State -1]
type = ChangeState
value = 3005
triggerall = command = Haosoboken_b
triggerall = power >= 2000 ;Level 2
trigger1 = statetype != A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Haosoboken
[State -1]
type = ChangeState
value = 3004
triggerall = command = Haosoboken_a
triggerall = power >= 1000 ;Level 1
trigger1 = statetype != A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Haosoboken
[State -1]
type = ChangeState
value = 3001
triggerall = command = Haosoboken_b
triggerall = power >= 1000 ;Level 1
trigger1 = statetype != A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;MueShinppudankiaku 
[State -1]
type = ChangeState
value = 3100
triggerall = command = Mue
triggerall = power >= 2000 ;Level 2
trigger1 = statetype != A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;MueShinppudankiaku 
[State -1]
type = ChangeState
value = 3000
triggerall = command = Mue
triggerall = power >= 1000 ;Level 1
trigger1 = statetype != A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Kouken_a
[State -1]
type = ChangeState
value = 1030
triggerall = command = Kouken
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Iuingstin
[State -1]
type = ChangeState
value = 1034
triggerall = command = iuing
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Iuingstin
[State -1]
type = VarSet
v = 1
value = 1
triggerall = stateno = 1034
triggerall = time > 1
trigger1 = command = iuing
;---------------------------------------------------------------------------
;Kof99 Fireball
[State -1]
type = VarSet
v = 1
value = 1
triggerall = stateno = 1005
trigger1 = command = x
trigger2 = command = a
;---------------------------------------------------------------------------
;HiensuShuppukiaku 94
[State -1]
type = ChangeState
value = 1076
triggerall = command = Hien_94
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;HiensuShuppukiaku 98
[State -1]
type = ChangeState
value = 1070
triggerall = command = HiensuShuppukiaku_98
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
; Ryuga_A
[State -1]
type = ChangeState
value = 1500
triggerall = command = Ryuga_a
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movehit = 1
trigger3 = stateno = 201
trigger3 = movehit = 1
trigger4 = stateno = 211
trigger4 = movehit = 1
trigger5 = stateno = 221
trigger5 = movehit = 1
trigger6 = stateno = 231
trigger6 = movehit = 1
trigger7 = stateno = 400
trigger7 = movehit = 1
trigger8 = stateno = 420
trigger8 = movehit = 1
trigger9 = stateno = 430
trigger9 = movehit = 1
;---------------------------------------------------------------------------
; Ryuga_A
[State -1]
type = ChangeState
value = 1525
triggerall = command = Ryuga_b
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movehit = 1
trigger3 = stateno = 201
trigger3 = movehit = 1
trigger4 = stateno = 211
trigger4 = movehit = 1
trigger5 = stateno = 221
trigger5 = movehit = 1
trigger6 = stateno = 231
trigger6 = movehit = 1
trigger7 = stateno = 400
trigger7 = movehit = 1
trigger8 = stateno = 420
trigger8 = movehit = 1
trigger9 = stateno = 430
trigger9 = movehit = 1
;---------------------------------------------------------------------------
; Ryuzan Sho_a
[State -1]
type = ChangeState
value = 1506
triggerall = command = Ryuzan_a
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movehit = 1
trigger3 = stateno = 201
trigger3 = movehit = 1
trigger4 = stateno = 211
trigger4 = movehit = 1
trigger5 = stateno = 221
trigger5 = movehit = 1
trigger6 = stateno = 231
trigger6 = movehit = 1
trigger7 = stateno = 400
trigger7 = movehit = 1
trigger8 = stateno = 420
trigger8 = movehit = 1
trigger9 = stateno = 430
trigger9 = movehit = 1
;---------------------------------------------------------------------------
; Ryuzan Sho_b
[State -1]
type = ChangeState
value = 1518
triggerall = command = Ryuzan_b
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movehit = 1
trigger3 = stateno = 201
trigger3 = movehit = 1
trigger4 = stateno = 211
trigger4 = movehit = 1
trigger5 = stateno = 221
trigger5 = movehit = 1
trigger6 = stateno = 231
trigger6 = movehit = 1
trigger7 = stateno = 400
trigger7 = movehit = 1
trigger8 = stateno = 420
trigger8 = movehit = 1
trigger9 = stateno = 430
trigger9 = movehit = 1
;---------------------------------------------------------------------------
;Engiten_b
[State -1]
type = ChangeState
value = 1102
triggerall = command = Engi_b
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 401
trigger4 = movecontact = 1
trigger5 = stateno = 411
trigger5 = movecontact = 1
trigger6 = stateno = 222
trigger6 = movecontact = 1
trigger7 = stateno = 223
trigger7 = movecontact = 1
;---------------------------------------------------------------------------
;Engiteen_a
[State -1]
type = ChangeState
value = 1103
triggerall = command = Engi_a
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 401
trigger4 = movecontact = 1
trigger5 = stateno = 411
trigger5 = movecontact = 1
trigger6 = stateno = 222
trigger6 = movecontact = 1
trigger7 = stateno = 223
trigger7 = movecontact = 1
;---------------------------------------------------------------------------
;RunFwd
[State -1]
type = ChangeState
value = 100
trigger1 = command = FF
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;HiensuRolling Tack
[State -1]
type = ChangeState
value = 641
trigger1 = command = hk
trigger1 = statetype = A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;RunBack
[State -1]
type = ChangeState
value = 105
trigger1 = command = BB
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Stand_Throw (close dir+b)
; Complicated? Skip the throws and look at stand_a, etc, first.
; This is disabled right now. Remove the "null;" below when you
; want to use it.
[State -1]
type = null;ChangeState
value = 900
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = p2bodydist X < 5 ;Near P2
trigger1 = command = fwd_b   ;p2 stand
trigger1 = stateno != 100    ;Not running
trigger1 = p2statetype = S
trigger1 = p2movetype != H
trigger2 = command = fwd_b   ;p2 crouch
trigger2 = stateno != 100    ;Not running
trigger2 = p2statetype = C
trigger2 = p2movetype != H
;---------------------------------------------------------------------------
;Stand_Throw (close dir+y)
; Complicated? Skip the throws and look at stand_a, etc, first.
; This is disabled right now. Remove the "null;" below when you
; want to use it.
[State -1]
type = null;ChangeState
value = 902
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = p2bodydist X < 5 ;Near P2
trigger1 = command = fwd_y   ;p2 stand
trigger1 = stateno != 100    ;Not running
trigger1 = p2statetype = S
trigger1 = p2movetype != H
trigger2 = command = fwd_y   ;p2 crouch
trigger2 = stateno != 100    ;Not running
trigger2 = p2statetype = C
trigger2 = p2movetype != H
;===========================================================================
;---------------------------------------------------------------------------
;Stand_A
[State -1]
type = ChangeState
value = 200
triggerall = command = a
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Stand_X
[State -1]
type = ChangeState
value = 210
triggerall = command = x
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Stand_B
[State -1]
type = ChangeState
value = 231
triggerall = command = b      
triggerall = command != holddown  
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Stand_Y
[State -1]
type = ChangeState
value = 240
triggerall = command = y      
triggerall = command != holddown  
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Crouch_A
[State -1]
type = ChangeState
value = 400
triggerall = command = a
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Crouch_X
[State -1]
type = ChangeState
value = 410
triggerall = command = x
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Crouch_B
[State -1]
type = ChangeState
value = 430
triggerall = command = b
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Crouch_Y
[State -1]
type = ChangeState
value = 440
triggerall = command = y
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Jump_A
[State -1]
type = ChangeState
value = 600
trigger1 = command = a
trigger1 = statetype = A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Jump_X
[State -1]
type = ChangeState
value = 610
trigger1 = command = x
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jump_B
[State -1]
type = ChangeState
value = 630
trigger1 = command = b
trigger1 = statetype = A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Jump_Y
[State -1]
type = ChangeState
value = 640
trigger1 = command = y
trigger1 = statetype = A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Stand_C
[State -1]
type = ChangeState
value = 320
triggerall = command = c
trigger1 = statetype = s
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Stand_C
[State -1]
type = ChangeState
value = 650
triggerall = command = c
trigger1 = statetype = A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Charge AX
[State -1]
type = ChangeState
value = 890
triggerall = power < 3000
trigger1 = command = hold_a
trigger1 = command = hold_x
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;ROLLFWD
[State -1]
type = ChangeState
value = 840
trigger1 = command = fwd_z
trigger1 = statetype = s
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;ROLLBWD
[State -1]
type = ChangeState
value = 841
trigger1 = command = back_z
trigger1 = statetype = s
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Esc
[State -1]
type = ChangeState
value = 920
triggerall = command = z
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
; Guard reversal
[State -1]
type = ChangeState
value = 745
triggerall = command = c
triggerall = power >= 500
trigger1 = stateno >= 150
trigger1 = stateno <= 153
;---------------------------------------------------------------------------
; Guard cancel roll (forward)
[State -1]
type = ChangeState
value = 750
triggerall = command = fwd_z
triggerall = power >= 500
trigger1 = stateno >= 150
trigger1 = stateno <= 153
;---------------------------------------------------------------------------
; Guard cancel roll (backwards)
[State -1]
type = ChangeState
value = 755
triggerall = command = back_z
triggerall = power >= 500
trigger1 = stateno >= 150
trigger1 = stateno <= 153
;---------------------------------------------------------------------------
; Dodge attack
[State -1]
type = ChangeState
value = 705
triggerall = stateno = 920
triggerall = AnimElem = 2, >= 0
trigger1 = command = x
trigger2 = command = y
trigger3 = command = a
trigger4 = command = b
;---------------------------------------------------------------------------
; Taunt
[State -1]
type = ChangeState
value = 195
trigger1 = command = s
trigger1 = command != holddown
trigger1 = statetype = S
trigger1 = ctrl = 1