; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands are given below. Delete, add, or modify as you wish.

;-| Super Motions |--------------------------------------------------------
; KAISER WAVE X
[Command]
name = FHCF_x
command = ~F, B, DB, D, DF, F, x
time = 20

; KAISER WAVE Y
[Command]
name = FHCF_y
command = ~F, B, DB, D, DF, F, y
time = 20

; KAISER WAVE Z
[Command]
name = FHCF_z
command = ~F, B, DB, D, DF, F, z
time = 20

; GIGATECH PRESSURE X
[Command]
name = QCFHCB_x
command = ~D, DF, F, DF, D, DB, B, x
time = 30

; GIGATECH PRESSURE Y
[Command]
name = QCFHCB_y
command = ~D, DF, F, DF, D, DB, B, y
time = 30

; GIGATECH PRESSURE Z
[Command]
name = QCFHCB_z
command = ~D, DF, F, DF, D, DB, B, z
time = 30

;-| Special Motions |------------------------------------------------------
;-----------------
; QCF
[Command]
name = QCF_a
command = ~D, DF, F, a
time = 17

[Command]
name = QCF_b
command = ~D, DF, F, b
time = 17

[Command]
name = QCF_c
command = ~D, DF, F, c
time = 17

[Command]
name = QCF_x
command = ~D, DF, F, x

[Command]
name = QCF_y
command = ~D, DF, F, y

[Command]
name = QCF_z
command = ~D, DF, F, z

;-----------------
; QCB
[Command]
name = QCB_a
command = ~D, DB, B, a

[Command]
name = QCB_b
command = ~D, DB, B, b

[Command]
name = QCB_c
command = ~D, DB, B, c

[Command]
name = QCB_x
command = ~D, DB, B, x

[Command]
name = QCB_y
command = ~D, DB, B, y

[Command]
name = QCB_z
command = ~D, DB, B, z

;-----------------
;GENOCIDE CUTTERS

[Command]
name = GC_a
command = ~F, D, DF, a
time = 13

[Command]
name = GC_b
command = ~F, D, DF, b
time = 13

[Command]
name = GC_c
command = ~F, D, DF, c
time = 13

;-----------------
; GOD PRESS
[Command]
name = HCB_x
command = ~F, DF, D, DB, B, x
time = 17

[Command]
name = HCB_y
command = ~F, DF, D, DB, B, y
time = 17

[Command]
name = HCB_z
command = ~F, DF, D, DB, B, z
time = 17

;--------------------
;Charge_Down_up
[Command]
name = chargedownup_a
command = ~60$D, U, a
time = 10

[Command]
name = chargedownup_b
command = ~60$D, U, b
time = 10

[Command]
name = chargedownup_c
command = ~60$D, U, c
time = 10

[Command]
name = chargedownup_x
command = ~60$D, U, x
time = 10

[Command]
name = chargedownup_y
command = ~60$D, U, y
time = 10

[Command]
name = chargedownup_z
command = ~60$D, U, z
time = 10

;--------------------
;Charge_Back_fwd
[Command]
name = chargebackfwd_a
command = ~60$B, F, a
time = 10

[Command]
name = chargebackfwd_b
command = ~60$B, F, b
time = 10

[Command]
name = chargedownup_c
command = ~60$D, U, c
time = 10

[Command]
name = chargedownup_x
command = ~60$D, U, x
time = 10

[Command]
name = chargedownup_y
command = ~60$D, U, y
time = 10

[Command]
name = chargedownup_z
command = ~60$D, U, z
time = 10

;-| Double Tap |-----------------------------------------------------------
[Command]
name = FF       ;Required (do not remove)
command = F, F
time = 10

[Command]
name = BB       ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = recovery ;Required (do not remove)
command = a+b
time = 1

[Command]
name = ab
command = a+b
time = 1

[Command]
name = xy
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = fwd_a
command = /F,a
time = 1

[Command]
name = fwd_b
command = /F,b
time = 1

[Command]
name = fwd_c
command = /F,c
time = 1

[Command]
name = fwd_x
command = /F,x
time = 1

[Command]
name = fwd_y
command = /F,y
time = 1

[Command]
name = fwd_z
command = /F,z
time = 1

[Command]
name = back_a
command = /B,a
time = 1

[Command]
name = back_b
command = /B,b
time = 1

[Command]
name = back_c
command = /B,c
time = 1

[Command]
name = down_a
command = /$D,a
time = 1

[Command]
name = down_b
command = /$D,b
time = 1

[Command]
name = down_c
command = /$D,c
time = 1

[Command]
name = fwd_ab
command = /F, a+b
time = 1

[Command]
name = back_ab
command = /B, a+b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = a
command = a
time = 1

[Command]
name = b
command = b
time = 1

[Command]
name = c
command = c
time = 1

[Command]
name = x
command = x
time = 1

[Command]
name = y
command = y
time = 1

[Command]
name = z
command = z
time = 1

[Command]
name = s
command = s
time = 1

;-| Hold Button |-----------------------------------------------------------
[Command]
name = hold_x
command = /x
time = 1

[Command]
name = hold_y
command = /y
time = 1

[Command]
name = hold_z
command = /z
time = 1

[Command]
name = hold_a
command = /a
time = 1

[Command]
name = hold_b
command = /b
time = 1

[Command]
name = hold_c
command = /c
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = holdfwd  ;Required (do not remove)
command = /$F
time = 1

[Command]
name = holdback ;Required (do not remove)
command = /$B
time = 1

[Command]
name = holdup   ;Required (do not remove)
command = /$U
time = 1

[Command]
name = holddown ;Required (do not remove)
command = /$D
time = 1


;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in. 


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
; Kaiser Wave 1 ('95)
[State -1]
type = ChangeState
value = 4110
triggerall = command = FHCF_x
triggerall = power >= 1000 ;Level 1
triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 203
trigger4 = movecontact = 1
trigger5 = stateno = 204
trigger5 = movecontact = 1
trigger6 = stateno = 205
trigger6 = movecontact = 1
trigger7 = stateno = 206
trigger7 = movecontact = 1
trigger8 = stateno = 210
trigger8 = movecontact = 1
trigger9 = stateno = 212
trigger9 = movecontact = 1
trigger10 = stateno = 213
trigger10 = movecontact = 1
trigger11 = stateno = 216
trigger11 = movecontact = 1
trigger12 = stateno = 220
trigger12 = movecontact = 1
trigger13 = stateno = 214
trigger13 = movecontact = 1
trigger14 = stateno = 215
trigger14 = AnimElem = 5
trigger14 = movecontact = 1
trigger15 = stateno = 221
trigger15 = movecontact = 1
trigger16 = stateno = 230
trigger16 = movecontact = 1
trigger17 = stateno = 231
trigger17 = movecontact = 1
trigger18 = stateno = 232
trigger18 = movecontact = 1
trigger19 = stateno = 233
trigger19 = movecontact = 1
trigger20 = stateno = 234
trigger20 = movecontact = 1
trigger21 = stateno = 235
trigger21 = movecontact = 1
trigger22 = stateno = 705
trigger22 = movecontact = 1

;---------------------------------------------------------------------------
; Kaiser Wave 2 ('96)
[State -1]
type = ChangeState
value = 4120
triggerall = command = FHCF_y
triggerall = power >= 1000 ;Level 1
triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 203
trigger4 = movecontact = 1
trigger5 = stateno = 204
trigger5 = movecontact = 1
trigger6 = stateno = 205
trigger6 = movecontact = 1
trigger7 = stateno = 206
trigger7 = movecontact = 1
trigger8 = stateno = 210
trigger8 = movecontact = 1
trigger9 = stateno = 212
trigger9 = movecontact = 1
trigger10 = stateno = 213
trigger10 = movecontact = 1
trigger11 = stateno = 216
trigger11 = movecontact = 1
trigger12 = stateno = 220
trigger12 = movecontact = 1
trigger13 = stateno = 214
trigger13 = movecontact = 1
trigger14 = stateno = 215
trigger14 = AnimElem = 5
trigger14 = movecontact = 1
trigger15 = stateno = 221
trigger15 = movecontact = 1
trigger16 = stateno = 230
trigger16 = movecontact = 1
trigger17 = stateno = 231
trigger17 = movecontact = 1
trigger18 = stateno = 232
trigger18 = movecontact = 1
trigger19 = stateno = 233
trigger19 = movecontact = 1
trigger20 = stateno = 234
trigger20 = movecontact = 1
trigger21 = stateno = 235
trigger21 = movecontact = 1
trigger22 = stateno = 705
trigger22 = movecontact = 1
        
;---------------------------------------------------------------------------
; Kaiser Wave 3 ('98)
[State -1]
type = ChangeState
value = 4130
triggerall = command = FHCF_z
triggerall = power >= 1000 ;Level 1
triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 203
trigger4 = movecontact = 1
trigger5 = stateno = 204
trigger5 = movecontact = 1
trigger6 = stateno = 205
trigger6 = movecontact = 1
trigger7 = stateno = 206
trigger7 = movecontact = 1
trigger8 = stateno = 210
trigger8 = movecontact = 1
trigger9 = stateno = 212
trigger9 = movecontact = 1
trigger10 = stateno = 213
trigger10 = movecontact = 1
trigger11 = stateno = 216
trigger11 = movecontact = 1
trigger12 = stateno = 220
trigger12 = movecontact = 1
trigger13 = stateno = 214
trigger13 = movecontact = 1
trigger14 = stateno = 215
trigger14 = AnimElem = 5
trigger14 = movecontact = 1
trigger15 = stateno = 221
trigger15 = movecontact = 1
trigger16 = stateno = 230
trigger16 = movecontact = 1
trigger17 = stateno = 231
trigger17 = movecontact = 1
trigger18 = stateno = 232
trigger18 = movecontact = 1
trigger19 = stateno = 233
trigger19 = movecontact = 1
trigger20 = stateno = 234
trigger20 = movecontact = 1
trigger21 = stateno = 235
trigger21 = movecontact = 1
trigger22 = stateno = 705
trigger22 = movecontact = 1

;---------------------------------------------------------------------------
; Gigatech Pressure
[State -1]
type = ChangeState
value = 4500
triggerall = command = QCFHCB_x
triggerall = power >= 1000 ;Level 1
triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 204
trigger4 = movecontact = 1
trigger5 = stateno = 205
trigger5 = movecontact = 1
trigger6 = stateno = 210
trigger6 = movecontact = 1
trigger7 = stateno = 216
trigger7 = movecontact = 1
trigger8 = stateno = 212
trigger8 = movecontact = 1
trigger9 = stateno = 213
trigger9 = movecontact = 1
trigger10 = stateno = 214
trigger10 = movecontact = 1
trigger10 = stateno = 215
trigger11 = AnimElem = 5
trigger11 = movecontact = 1
trigger12 = stateno = 221
trigger12 = movecontact = 1
trigger13 = stateno = 230
trigger13 = movecontact = 1
trigger14 = stateno = 231
trigger14 = movecontact = 1
trigger15 = stateno = 232
trigger15 = movecontact = 1
trigger16 = stateno = 233
trigger16 = movecontact = 1
trigger17 = stateno = 234
trigger17 = movecontact = 1
trigger18 = stateno = 235
trigger18 = movecontact = 1
trigger19 = stateno = 230
trigger19 = movecontact = 1
trigger20 = stateno = 231
trigger20 = movecontact = 1
trigger21 = stateno = 232
trigger21 = movecontact = 1
trigger22 = stateno = 233
trigger22 = movecontact = 1
trigger23 = stateno = 234
trigger23 = movecontact = 1
trigger24 = stateno = 235
trigger24 = movecontact = 1
trigger25 = stateno = 705
trigger25 = movecontact = 1

;---------------------------------------------------------------------------
; Double Gigatech Pressure
[State -1]
type = ChangeState
value = 4510
triggerall = command = QCFHCB_y
triggerall = power >= 2000 ;Level 2
triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 204
trigger4 = movecontact = 1
trigger5 = stateno = 205
trigger5 = movecontact = 1
trigger6 = stateno = 210
trigger6 = movecontact = 1
trigger7 = stateno = 216
trigger7 = movecontact = 1
trigger8 = stateno = 212
trigger8 = movecontact = 1
trigger9 = stateno = 213
trigger9 = movecontact = 1
trigger10 = stateno = 214
trigger10 = movecontact = 1
trigger10 = stateno = 215
trigger11 = AnimElem = 5
trigger11 = movecontact = 1
trigger12 = stateno = 221
trigger12 = movecontact = 1
trigger13 = stateno = 230
trigger13 = movecontact = 1
trigger14 = stateno = 231
trigger14 = movecontact = 1
trigger15 = stateno = 232
trigger15 = movecontact = 1
trigger16 = stateno = 233
trigger16 = movecontact = 1
trigger17 = stateno = 234
trigger17 = movecontact = 1
trigger18 = stateno = 235
trigger18 = movecontact = 1
trigger19 = stateno = 230
trigger19 = movecontact = 1
trigger20 = stateno = 231
trigger20 = movecontact = 1
trigger21 = stateno = 232
trigger21 = movecontact = 1
trigger22 = stateno = 233
trigger22 = movecontact = 1
trigger23 = stateno = 234
trigger23 = movecontact = 1
trigger24 = stateno = 235
trigger24 = movecontact = 1
trigger25 = stateno = 705
trigger25 = movecontact = 1

;---------------------------------------------------------------------------
; Final Gigatech Pressure
[State -1]
type = null; ChangeState
value = 4520
triggerall = command = QCFHCB_z
triggerall = power >= 3000 ;Level 3
triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 204
trigger4 = movecontact = 1
trigger5 = stateno = 205
trigger5 = movecontact = 1
trigger6 = stateno = 210
trigger6 = movecontact = 1
trigger7 = stateno = 216
trigger7 = movecontact = 1
trigger8 = stateno = 212
trigger8 = movecontact = 1
trigger9 = stateno = 213
trigger9 = movecontact = 1
trigger10 = stateno = 214
trigger10 = movecontact = 1
trigger10 = stateno = 215
trigger11 = AnimElem = 5
trigger11 = movecontact = 1
trigger12 = stateno = 221
trigger12 = movecontact = 1
trigger13 = stateno = 230
trigger13 = movecontact = 1
trigger14 = stateno = 231
trigger14 = movecontact = 1
trigger15 = stateno = 232
trigger15 = movecontact = 1
trigger16 = stateno = 233
trigger16 = movecontact = 1
trigger17 = stateno = 234
trigger17 = movecontact = 1
trigger18 = stateno = 235
trigger18 = movecontact = 1
trigger19 = stateno = 230
trigger19 = movecontact = 1
trigger20 = stateno = 231
trigger20 = movecontact = 1
trigger21 = stateno = 232
trigger21 = movecontact = 1
trigger22 = stateno = 233
trigger22 = movecontact = 1
trigger23 = stateno = 234
trigger23 = movecontact = 1
trigger24 = stateno = 235
trigger24 = movecontact = 1
trigger25 = stateno = 705
trigger25 = movecontact = 1

;---------------------------------------------------------------------------
; Genocide Cutter
[State -1]
type = ChangeState
value = 2000
triggerall = command = GC_a
triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 204
trigger4 = movecontact = 1
trigger5 = stateno = 205
trigger5 = movecontact = 1
trigger6 = stateno = 210
trigger6 = movecontact = 1
trigger7 = stateno = 216
trigger7 = movecontact = 1
trigger8 = stateno = 212
trigger8 = movecontact = 1
trigger9 = stateno = 213
trigger9 = movecontact = 1
trigger10 = stateno = 214
trigger10 = movecontact = 1
trigger10 = stateno = 215
trigger11 = AnimElem = 5
trigger11 = movecontact = 1
trigger12 = stateno = 221
trigger12 = movecontact = 1
trigger13 = stateno = 230
trigger13 = movecontact = 1
trigger14 = stateno = 231
trigger14 = movecontact = 1
trigger15 = stateno = 232
trigger15 = movecontact = 1
trigger16 = stateno = 233
trigger16 = movecontact = 1
trigger17 = stateno = 234
trigger17 = movecontact = 1
trigger18 = stateno = 235
trigger18 = movecontact = 1
trigger19 = stateno = 230
trigger19 = movecontact = 1
trigger20 = stateno = 231
trigger20 = movecontact = 1
trigger21 = stateno = 232
trigger21 = movecontact = 1
trigger22 = stateno = 233
trigger22 = movecontact = 1
trigger23 = stateno = 234
trigger23 = movecontact = 1
trigger24 = stateno = 235
trigger24 = movecontact = 1
trigger25 = stateno = 705
trigger25 = movecontact = 1

;---------------------------------------------------------------------------
; Dark Genocide
[State -1]
type = ChangeState
value = 2100
triggerall = command = GC_b
triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 204
trigger4 = movecontact = 1
trigger5 = stateno = 205
trigger5 = movecontact = 1
trigger6 = stateno = 210
trigger6 = movecontact = 1
trigger7 = stateno = 216
trigger7 = movecontact = 1
trigger8 = stateno = 212
trigger8 = movecontact = 1
trigger9 = stateno = 213
trigger9 = movecontact = 1
trigger10 = stateno = 214
trigger10 = movecontact = 1
trigger11 = stateno = 215
trigger11 = AnimElem = 5
trigger11 = movecontact = 1
trigger12 = stateno = 221
trigger12 = movecontact = 1
trigger13 = stateno = 230
trigger13 = movecontact = 1
trigger14 = stateno = 231
trigger14 = movecontact = 1
trigger15 = stateno = 232
trigger15 = movecontact = 1
trigger16 = stateno = 233
trigger16 = movecontact = 1
trigger17 = stateno = 234
trigger17 = movecontact = 1
trigger18 = stateno = 235
trigger18 = movecontact = 1
trigger19 = stateno = 705
trigger19 = movecontact = 1

;---------------------------------------------------------------------------
 Lunar Genocide
[State -1]
type = ChangeState
value = 2200
triggerall = command = GC_c
triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 204
trigger4 = movecontact = 1
trigger5 = stateno = 205
trigger5 = movecontact = 1
trigger6 = stateno = 210
trigger6 = movecontact = 1
trigger7 = stateno = 216
trigger7 = movecontact = 1
trigger8 = stateno = 212
trigger8 = movecontact = 1
trigger9 = stateno = 213
trigger9 = movecontact = 1
trigger10 = stateno = 214
trigger10 = movecontact = 1
trigger11 = stateno = 215
trigger11 = AnimElem = 5
trigger11 = movecontact = 1
trigger12 = stateno = 221
trigger12 = movecontact = 1
trigger13 = stateno = 230
trigger13 = movecontact = 1
trigger14 = stateno = 231
trigger14 = movecontact = 1
trigger15 = stateno = 232
trigger15 = movecontact = 1
trigger16 = stateno = 233
trigger16 = movecontact = 1
trigger17 = stateno = 234
trigger17 = movecontact = 1
trigger18 = stateno = 235
trigger18 = movecontact = 1
trigger19 = stateno = 705
trigger19 = movecontact = 1

;---------------------------------------------------------------------------
; Reppu Ken X
[State -1]
type = ChangeState
value = 1000
triggerall = command = QCF_x
triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 203
trigger4 = movecontact = 1
trigger5 = stateno = 204
trigger5 = movecontact = 1
trigger6 = stateno = 205
trigger6 = movecontact = 1
trigger7 = stateno = 206
trigger7 = movecontact = 1
trigger8 = stateno = 210
trigger8 = movecontact = 1
trigger9 = stateno = 212
trigger9 = movecontact = 1
trigger10 = stateno = 213
trigger10 = movecontact = 1
trigger11 = stateno = 216
trigger11 = movecontact = 1
trigger12 = stateno = 220
trigger12 = movecontact = 1
trigger13 = stateno = 214
trigger13 = movecontact = 1
trigger14 = stateno = 215
trigger14 = AnimElem = 5
trigger14 = movecontact = 1
trigger15 = stateno = 221
trigger15 = movecontact = 1
trigger16 = stateno = 230
trigger16 = movecontact = 1
trigger17 = stateno = 231
trigger17 = movecontact = 1
trigger18 = stateno = 232
trigger18 = movecontact = 1
trigger19 = stateno = 233
trigger19 = movecontact = 1
trigger20 = stateno = 234
trigger20 = movecontact = 1
trigger21 = stateno = 235
trigger21 = movecontact = 1
trigger22 = stateno = 705
trigger22 = movecontact = 1

;---------------------------------------------------------------------------
; Reppu Ken Y
[State -1]
type = ChangeState
value = 1001
triggerall = command = QCF_y
triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 203
trigger4 = movecontact = 1
trigger5 = stateno = 204
trigger5 = movecontact = 1
trigger6 = stateno = 205
trigger6 = movecontact = 1
trigger7 = stateno = 206
trigger7 = movecontact = 1
trigger8 = stateno = 210
trigger8 = movecontact = 1
trigger9 = stateno = 212
trigger9 = movecontact = 1
trigger10 = stateno = 213
trigger10 = movecontact = 1
trigger11 = stateno = 216
trigger11 = movecontact = 1
trigger12 = stateno = 220
trigger12 = movecontact = 1
trigger13 = stateno = 214
trigger13 = movecontact = 1
trigger14 = stateno = 215
trigger14 = AnimElem = 5
trigger14 = movecontact = 1
trigger15 = stateno = 221
trigger15 = movecontact = 1
trigger16 = stateno = 230
trigger16 = movecontact = 1
trigger17 = stateno = 231
trigger17 = movecontact = 1
trigger18 = stateno = 232
trigger18 = movecontact = 1
trigger19 = stateno = 233
trigger19 = movecontact = 1
trigger20 = stateno = 234
trigger20 = movecontact = 1
trigger21 = stateno = 235
trigger21 = movecontact = 1
trigger22 = stateno = 705
trigger22 = movecontact = 1

;---------------------------------------------------------------------------
; Reppu Ken Z
[State -1]
type = ChangeState
value = 1002
triggerall = command = QCF_z
triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 203
trigger4 = movecontact = 1
trigger5 = stateno = 204
trigger5 = movecontact = 1
trigger6 = stateno = 205
trigger6 = movecontact = 1
trigger7 = stateno = 206
trigger7 = movecontact = 1
trigger8 = stateno = 210
trigger8 = movecontact = 1
trigger9 = stateno = 212
trigger9 = movecontact = 1
trigger10 = stateno = 213
trigger10 = movecontact = 1
trigger11 = stateno = 216
trigger11 = movecontact = 1
trigger12 = stateno = 220
trigger12 = movecontact = 1
trigger13 = stateno = 214
trigger13 = movecontact = 1
trigger14 = stateno = 215
trigger14 = AnimElem = 5
trigger14 = movecontact = 1
trigger15 = stateno = 221
trigger15 = movecontact = 1
trigger16 = stateno = 230
trigger16 = movecontact = 1
trigger17 = stateno = 231
trigger17 = movecontact = 1
trigger18 = stateno = 232
trigger18 = movecontact = 1
trigger19 = stateno = 233
trigger19 = movecontact = 1
trigger20 = stateno = 234
trigger20 = movecontact = 1
trigger21 = stateno = 235
trigger21 = movecontact = 1
trigger22 = stateno = 705
trigger22 = movecontact = 1

;---------------------------------------------------------------------------
; God Press X
[State -1]
type = ChangeState
value = 1500
triggerall = command = HCB_x
triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 204
trigger4 = movecontact = 1
trigger5 = stateno = 205
trigger5 = movecontact = 1
trigger6 = stateno = 210
trigger6 = movecontact = 1
trigger7 = stateno = 216
trigger7 = movecontact = 1
trigger8 = stateno = 212
trigger8 = movecontact = 1
trigger9 = stateno = 213
trigger9 = movecontact = 1
trigger10 = stateno = 214
trigger10 = movecontact = 1
trigger10 = stateno = 215
trigger11 = AnimElem = 5
trigger11 = movecontact = 1
trigger12 = stateno = 221
trigger12 = movecontact = 1
trigger13 = stateno = 230
trigger13 = movecontact = 1
trigger14 = stateno = 231
trigger14 = movecontact = 1
trigger15 = stateno = 232
trigger15 = movecontact = 1
trigger16 = stateno = 233
trigger16 = movecontact = 1
trigger17 = stateno = 234
trigger17 = movecontact = 1
trigger18 = stateno = 235
trigger18 = movecontact = 1
trigger19 = stateno = 230
trigger19 = movecontact = 1
trigger20 = stateno = 231
trigger20 = movecontact = 1
trigger21 = stateno = 232
trigger21 = movecontact = 1
trigger22 = stateno = 233
trigger22 = movecontact = 1
trigger23 = stateno = 234
trigger23 = movecontact = 1
trigger24 = stateno = 235
trigger24 = movecontact = 1
trigger25 = stateno = 705
trigger25 = movecontact = 1

;---------------------------------------------------------------------------
; God Press Y
[State -1]
type = ChangeState
value = 1510
triggerall = command = HCB_y
triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 204
trigger4 = movecontact = 1
trigger5 = stateno = 205
trigger5 = movecontact = 1
trigger6 = stateno = 210
trigger6 = movecontact = 1
trigger7 = stateno = 216
trigger7 = movecontact = 1
trigger8 = stateno = 212
trigger8 = movecontact = 1
trigger9 = stateno = 213
trigger9 = movecontact = 1
trigger10 = stateno = 214
trigger10 = movecontact = 1
trigger10 = stateno = 215
trigger11 = AnimElem = 5
trigger11 = movecontact = 1
trigger12 = stateno = 221
trigger12 = movecontact = 1
trigger13 = stateno = 230
trigger13 = movecontact = 1
trigger14 = stateno = 231
trigger14 = movecontact = 1
trigger15 = stateno = 232
trigger15 = movecontact = 1
trigger16 = stateno = 233
trigger16 = movecontact = 1
trigger17 = stateno = 234
trigger17 = movecontact = 1
trigger18 = stateno = 235
trigger18 = movecontact = 1
trigger19 = stateno = 230
trigger19 = movecontact = 1
trigger20 = stateno = 231
trigger20 = movecontact = 1
trigger21 = stateno = 232
trigger21 = movecontact = 1
trigger22 = stateno = 233
trigger22 = movecontact = 1
trigger23 = stateno = 234
trigger23 = movecontact = 1
trigger24 = stateno = 235
trigger24 = movecontact = 1
trigger25 = stateno = 705
trigger25 = movecontact = 1

;---------------------------------------------------------------------------
; God Press Z
[State -1]
type = ChangeState
value = 1510
triggerall = command = HCB_z
triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 204
trigger4 = movecontact = 1
trigger5 = stateno = 205
trigger5 = movecontact = 1
trigger6 = stateno = 210
trigger6 = movecontact = 1
trigger7 = stateno = 216
trigger7 = movecontact = 1
trigger8 = stateno = 212
trigger8 = movecontact = 1
trigger9 = stateno = 213
trigger9 = movecontact = 1
trigger10 = stateno = 214
trigger10 = movecontact = 1
trigger10 = stateno = 215
trigger11 = AnimElem = 5
trigger11 = movecontact = 1
trigger12 = stateno = 221
trigger12 = movecontact = 1
trigger13 = stateno = 230
trigger13 = movecontact = 1
trigger14 = stateno = 231
trigger14 = movecontact = 1
trigger15 = stateno = 232
trigger15 = movecontact = 1
trigger16 = stateno = 233
trigger16 = movecontact = 1
trigger17 = stateno = 234
trigger17 = movecontact = 1
trigger18 = stateno = 235
trigger18 = movecontact = 1
trigger19 = stateno = 230
trigger19 = movecontact = 1
trigger20 = stateno = 231
trigger20 = movecontact = 1
trigger21 = stateno = 232
trigger21 = movecontact = 1
trigger22 = stateno = 233
trigger22 = movecontact = 1
trigger23 = stateno = 234
trigger23 = movecontact = 1
trigger24 = stateno = 235
trigger24 = movecontact = 1
trigger25 = stateno = 705
trigger25 = movecontact = 1

;---------------------------------------------------------------------------
; Dark Barrier A
[State -1]
type = ChangeState
value = 1200
triggerall = command = QCF_a
triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 203
trigger4 = movecontact = 1
trigger5 = stateno = 204
trigger5 = movecontact = 1
trigger6 = stateno = 205
trigger6 = movecontact = 1
trigger7 = stateno = 206
trigger7 = movecontact = 1
trigger8 = stateno = 210
trigger8 = movecontact = 1
trigger9 = stateno = 212
trigger9 = movecontact = 1
trigger10 = stateno = 213
trigger10 = movecontact = 1
trigger11 = stateno = 216
trigger11 = movecontact = 1
trigger12 = stateno = 220
trigger12 = movecontact = 1
trigger13 = stateno = 214
trigger13 = movecontact = 1
trigger14 = stateno = 215
trigger14 = AnimElem = 5
trigger14 = movecontact = 1
trigger15 = stateno = 221
trigger15 = movecontact = 1
trigger16 = stateno = 230
trigger16 = movecontact = 1
trigger17 = stateno = 231
trigger17 = movecontact = 1
trigger18 = stateno = 232
trigger18 = movecontact = 1
trigger19 = stateno = 233
trigger19 = movecontact = 1
trigger20 = stateno = 234
trigger20 = movecontact = 1
trigger21 = stateno = 235
trigger21 = movecontact = 1
trigger22 = stateno = 705
trigger22 = movecontact = 1

;---------------------------------------------------------------------------
; Dark Barrier B
[State -1]
type = ChangeState
value = 1210
triggerall = command = QCF_b
triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 203
trigger4 = movecontact = 1
trigger5 = stateno = 204
trigger5 = movecontact = 1
trigger6 = stateno = 205
trigger6 = movecontact = 1
trigger7 = stateno = 206
trigger7 = movecontact = 1
trigger8 = stateno = 210
trigger8 = movecontact = 1
trigger9 = stateno = 212
trigger9 = movecontact = 1
trigger10 = stateno = 213
trigger10 = movecontact = 1
trigger11 = stateno = 216
trigger11 = movecontact = 1
trigger12 = stateno = 220
trigger12 = movecontact = 1
trigger13 = stateno = 214
trigger13 = movecontact = 1
trigger14 = stateno = 215
trigger14 = AnimElem = 5
trigger14 = movecontact = 1
trigger15 = stateno = 221
trigger15 = movecontact = 1
trigger16 = stateno = 230
trigger16 = movecontact = 1
trigger17 = stateno = 231
trigger17 = movecontact = 1
trigger18 = stateno = 232
trigger18 = movecontact = 1
trigger19 = stateno = 233
trigger19 = movecontact = 1
trigger20 = stateno = 234
trigger20 = movecontact = 1
trigger21 = stateno = 235
trigger21 = movecontact = 1
trigger22 = stateno = 705
trigger22 = movecontact = 1

;---------------------------------------------------------------------------
; Dark Barrier C
[State -1]
type = ChangeState
value = 1220
triggerall = command = QCF_c
triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 201
trigger3 = movecontact = 1
trigger4 = stateno = 203
trigger4 = movecontact = 1
trigger5 = stateno = 204
trigger5 = movecontact = 1
trigger6 = stateno = 205
trigger6 = movecontact = 1
trigger7 = stateno = 206
trigger7 = movecontact = 1
trigger8 = stateno = 210
trigger8 = movecontact = 1
trigger9 = stateno = 212
trigger9 = movecontact = 1
trigger10 = stateno = 213
trigger10 = movecontact = 1
trigger11 = stateno = 216
trigger11 = movecontact = 1
trigger12 = stateno = 220
trigger12 = movecontact = 1
trigger13 = stateno = 214
trigger13 = movecontact = 1
trigger14 = stateno = 215
trigger14 = AnimElem = 5
trigger14 = movecontact = 1
trigger15 = stateno = 221
trigger15 = movecontact = 1
trigger16 = stateno = 230
trigger16 = movecontact = 1
trigger17 = stateno = 231
trigger17 = movecontact = 1
trigger18 = stateno = 232
trigger18 = movecontact = 1
trigger19 = stateno = 233
trigger19 = movecontact = 1
trigger20 = stateno = 234
trigger20 = movecontact = 1
trigger21 = stateno = 235
trigger21 = movecontact = 1
trigger22 = stateno = 705
trigger22 = movecontact = 1

;---------------------------------------------------------------------------
;RunFwd
[State -1]
type = ChangeState
value = 100
trigger1 = command = FF
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;RunBack
[State -1]
type = ChangeState
value = 105
trigger1 = command = BB
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Stand_Throw (close dir+b)
; Complicated? Skip the throws and look at stand_a, etc, first.
; This is disabled right now. Remove the "null;" below when you
; want to use it.
[State -1]
type = null; ChangeState
value = 900
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = p2bodydist X < 5 ;Near P2
trigger1 = command = fwd_b   ;p2 stand
trigger1 = stateno != 100    ;Not running
trigger1 = p2statetype = S
trigger1 = p2movetype != H
trigger2 = command = fwd_b   ;p2 crouch
trigger2 = stateno != 100    ;Not running
trigger2 = p2statetype = C
trigger2 = p2movetype != H
trigger3 = command = back_b  ;p2 stand
trigger3 = p2statetype = S
trigger3 = p2movetype != H
trigger4 = command = back_b  ;p2 crouch
trigger4 = p2statetype = C
trigger4 = p2movetype != H

;---------------------------------------------------------------------------
;Air_Throw1 (close dir+b)
; This is disabled right now. Remove the "null;" below when you
; want to use it.
[State -1]
type = null; ChangeState
value = 950
triggerall = statetype = A
triggerall = ctrl = 1
triggerall = p2bodydist X < 9
triggerall = p2bodydist Y > -22
triggerall = p2bodydist Y < 22
triggerall = p2statetype = A
triggerall = p2movetype != H
trigger1 = command = fwd_b
trigger2 = command = back_b


;===========================================================================
;---------------------------------------------------------------------------
; Dodge
[State -1]
type = ChangeState
value = 700
trigger1 = command = xy
trigger1 = statetype = S
trigger1 = command != holddown
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Dodge attack
[State -1]
type = ChangeState
value = 705
triggerall = stateno = 700
triggerall = AnimElem = 3, >= 0
trigger1 = command = x
trigger2 = command = y
trigger3 = command = z
trigger4 = command = a
trigger5 = command = b
trigger6 = command = c

;---------------------------------------------------------------------------
;Palm Strike
[State -1]
type = ChangeState
value = 220
triggerall = command = fwd_y       ;Place name of command here
triggerall = command != holddown  ;Standing moves should have this line
 ;The following is true if Player is in stand state, and has control
trigger1 = statetype = S
trigger1 = ctrl = 1
 ;Uncomment the following if you want to be able to do a Stand_A rapidly
trigger2 = stateno = 200
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 201
trigger3 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger4 = stateno = 203
trigger4 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger5 = stateno = 204
trigger5 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger6 = stateno = 205
trigger6 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger7 = stateno = 206
trigger7 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger8 = stateno = 210
trigger8 = movecontact = 1
trigger9 = stateno = 212
trigger9 = movecontact = 1
trigger10 = stateno = 213
trigger10 = movecontact = 1
trigger11 = stateno = 215
trigger11 = AnimElem = 5
trigger11 = movecontact = 1
trigger12 = stateno = 216
trigger12 = movecontact = 1
trigger13 = stateno = 230
trigger13 = movecontact = 1
trigger14 = stateno = 231
trigger14 = movecontact = 1
trigger15 = stateno = 232
trigger15 = movecontact = 1
trigger16 = stateno = 233
trigger16 = movecontact = 1
trigger17 = stateno = 234
trigger17 = movecontact = 1
trigger18 = stateno = 235
trigger18 = movecontact = 1
trigger19 = stateno = 705
trigger19 = movecontact = 1

;---------------------------------------------------------------------------
;Double Tomahawk
[State -1]
type = ChangeState
value = 221
triggerall = command = fwd_b       ;Place name of command here
triggerall = command != holddown  ;Standing moves should have this line
 ;The following is true if Player is in stand state, and has control
trigger1 = statetype = S
trigger1 = ctrl = 1
 ;Uncomment the following if you want to be able to do a Stand_A rapidly
trigger2 = stateno = 200
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 201
trigger3 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger4 = stateno = 203
trigger4 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger5 = stateno = 204
trigger5 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger6 = stateno = 205
trigger6 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger7 = stateno = 206
trigger7 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger8 = stateno = 210
trigger8 = movecontact = 1
trigger9 = stateno = 212
trigger9 = movecontact = 1
trigger10 = stateno = 213
trigger10 = movecontact = 1
trigger11 = stateno = 215
trigger11 = AnimElem = 5
trigger11 = movecontact = 1
trigger12 = stateno = 216
trigger12 = movecontact = 1
trigger13 = stateno = 230
trigger13 = movecontact = 1
trigger14 = stateno = 231
trigger14 = movecontact = 1
trigger15 = stateno = 232
trigger15 = movecontact = 1
trigger16 = stateno = 233
trigger16 = movecontact = 1
trigger17 = stateno = 234
trigger17 = movecontact = 1
trigger18 = stateno = 235
trigger18 = movecontact = 1
trigger19 = stateno = 705
trigger19 = movecontact = 1

;---------------------------------------------------------------------------
;Punch 1
[State -1]
type = ChangeState
value = 200
triggerall = command = x          ;Place name of command here
triggerall = command != holddown  ;Standing moves should have this line
triggerall = P2bodydist X > 34
 ;The following is true if Player is in stand state, and has control
trigger1 = statetype = S
trigger1 = ctrl = 1
 ;Uncomment the following if you want to be able to do a Stand_A rapidly
trigger2 = stateno = 705
trigger2 = movecontact = 1
trigger3 = stateno = 230
trigger3 = movecontact = 1
trigger4 = stateno = 233
trigger4 = movecontact = 1

;---------------------------------------------------------------------------
;Punch 2
[State -1]
type = ChangeState
value = 201
triggerall = command = y          ;Place name of command here
triggerall = command != holddown  ;Standing moves should have this line
triggerall = P2bodydist X > 10
trigger1 = statetype = S
trigger1 = ctrl = 1
 ;Uncomment the following if you want to be able to do a Stand_A rapidly
trigger2 = stateno = 200
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 204
trigger3 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 214
trigger5 = movecontact = 1
trigger6 = stateno = 705
trigger6 = movecontact = 1
trigger7 = stateno = 231
trigger7 = movecontact = 1
trigger8 = stateno = 234
trigger8 = movecontact = 1

;---------------------------------------------------------------------------
;Punch 3
[State -1]
type = ChangeState
value = 203
triggerall = command = z          ;Place name of command here
triggerall = command != holddown  ;Standing moves should have this line
 ;The following is true if Player is in stand state, and has control
triggerall = P2bodydist X > 42
trigger1 = statetype = S
trigger1 = ctrl = 1
 ;Uncomment the following if you want to be able to do a Stand_A rapidly
trigger2 = stateno = 200
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 201
trigger3 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger4 = stateno = 204
trigger4 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger5 = stateno = 205
trigger5 = movecontact = 1
trigger6 = stateno = 210
trigger6 = movecontact = 1
trigger7 = stateno = 212
trigger7 = movecontact = 1
trigger8 = stateno = 214
trigger8 = movecontact = 1
trigger9 = stateno = 215
trigger9 = AnimElem = 5
trigger9 = movecontact = 1
trigger10 = stateno = 705
trigger10 = movecontact = 1

;---------------------------------------------------------------------------
;Kick 1
[State -1]
type = ChangeState
value = 204
triggerall = command = a
triggerall = command != holddown
triggerall = P2bodydist X > 42
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 705
trigger4 = movecontact = 1
trigger5 = stateno = 230
trigger5 = movecontact = 1
trigger6 = stateno = 233
trigger6 = movecontact = 1

;---------------------------------------------------------------------------
;Kick 2
[State -1]
type = ChangeState
value = 205
triggerall = command = b
triggerall = command != holddown
triggerall = P2bodydist X > 28
trigger1 = statetype = S
trigger1 = ctrl = 1
 ;Uncomment the following if you want to be able to "chain" the attack
 ;from a Stand_A (state 200)
trigger2 = stateno = 200
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 204
trigger3 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger4 = stateno = 201
trigger4 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger5 = stateno = 210
trigger5 = movecontact = 1
trigger6 = stateno = 212
trigger6 = movecontact = 1
trigger7 = stateno = 214
trigger7 = movecontact = 1
trigger8 = stateno = 705
trigger8 = movecontact = 1

;---------------------------------------------------------------------------
;Kick 3
[State -1]
type = ChangeState
value = 206
triggerall = command = c
triggerall = command != holddown
triggerall = P2bodydist X > 40
trigger1 = statetype = S
trigger1 = ctrl = 1
 ;Uncomment the following if you want to be able to "chain" the attack
 ;from a Stand_A (state 200)
trigger2 = stateno = 200
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 201
trigger3 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger4 = stateno = 204
trigger4 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger5 = stateno = 205
trigger5 = movecontact = 1
trigger6 = stateno = 210
trigger6 = movecontact = 1
trigger7 = stateno = 212
trigger7 = movecontact = 1
trigger8 = stateno = 214
trigger8 = movecontact = 1
trigger9 = stateno = 215
trigger9 = AnimElem = 5
trigger9 = movecontact = 1
trigger10 = stateno = 705
trigger10 = movecontact = 1

;---------------------------------------------------------------------------
;Punch 1 (close)
[State -1]
type = ChangeState
value = 210
triggerall = command = x
triggerall = command != holddown
triggerall = P2bodydist X <= 34
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 705
trigger2 = movecontact = 1
trigger3 = stateno = 230
trigger3 = movecontact = 1
trigger4 = stateno = 233
trigger4 = movecontact = 1

;---------------------------------------------------------------------------
;Punch 2 (close)
[State -1]
type = ChangeState
value = 212
triggerall = command = y
triggerall = command != holddown
triggerall = P2bodydist X <= 10
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 204
trigger3 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 214
trigger5 = movecontact = 1
trigger6 = stateno = 705
trigger6 = movecontact = 1
trigger7 = stateno = 231
trigger7 = movecontact = 1
trigger8 = stateno = 234
trigger8 = movecontact = 1

;---------------------------------------------------------------------------
;Punch 3 (close)
[State -1]
type = ChangeState
value = 213
triggerall = command = z
triggerall = command != holddown
triggerall = P2bodydist X <= 42
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 201
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 204
trigger3 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger4 = stateno = 205
trigger4 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger5 = stateno = 210
trigger5 = movecontact = 1
trigger6 = stateno = 212
trigger6 = movecontact = 1
trigger7 = stateno = 214
trigger7 = movecontact = 1
trigger8 = stateno = 215
trigger8 = AnimElem = 5
trigger8 = movecontact = 1
trigger9 = stateno = 705
trigger9 = movecontact = 1

;---------------------------------------------------------------------------
;Kick 1 (close)
[State -1]
type = ChangeState
value = 214
triggerall = command = a
triggerall = command != holddown
triggerall = P2bodydist X <= 42
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 705
trigger4 = movecontact = 1
trigger5 = stateno = 230
trigger5 = movecontact = 1
trigger6 = stateno = 233
trigger6 = movecontact = 1

;---------------------------------------------------------------------------
;Kick 2 (close)
[State -1]
type = ChangeState
value = 215
triggerall = command = b
triggerall = command != holddown
triggerall = P2bodydist X <= 28
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 204
trigger3 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger4 = stateno = 201
trigger4 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger5 = stateno = 210
trigger5 = movecontact = 1
trigger6 = stateno = 212
trigger6 = movecontact = 1
trigger7 = stateno = 214
trigger7 = movecontact = 1
trigger8 = stateno = 705
trigger8 = movecontact = 1
trigger9 = stateno = 231
trigger9 = movecontact = 1
trigger10 = stateno = 234
trigger10 = movecontact = 1

;---------------------------------------------------------------------------
;Kick 3 (close)
[State -1]
type = ChangeState
value = 216
triggerall = command = c
triggerall = command != holddown
triggerall = P2bodydist X <= 40
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 201
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 204
trigger3 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 212
trigger5 = movecontact = 1
trigger6 = stateno = 214
trigger6 = movecontact = 1
trigger7 = stateno = 215
trigger7 = AnimElem = 5
trigger7 = movecontact = 1
trigger8 = stateno = 705
trigger8 = movecontact = 1

---------------------------------------------------------------------------
;Crouch Punch 1
[State -1]
type = ChangeState
value = 230
triggerall = command = x
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 204
trigger3 = movecontact = 1
trigger4 = stateno = 200
trigger4 = movecontact = 1
trigger5 = stateno = 204
trigger5 = movecontact = 1
trigger6 = stateno = 210
trigger6 = movecontact = 1
trigger7 = stateno = 214
trigger7 = movecontact = 1

---------------------------------------------------------------------------
;Crouch Punch 2
[State -1]
type = ChangeState
value = 231
triggerall = command = y
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 230
trigger2 = movecontact = 1
trigger3 = stateno = 233
trigger3 = movecontact = 1
trigger4 = stateno = 200
trigger4 = movecontact = 1
trigger5 = stateno = 204
trigger5 = movecontact = 1
trigger6 = stateno = 210
trigger6 = movecontact = 1
trigger7 = stateno = 214
trigger7 = movecontact = 1

;---------------------------------------------------------------------------
;Crouch Punch 3
[State -1]
type = ChangeState
value = 232
triggerall = command = z
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 230
trigger2 = movecontact = 1
trigger3 = stateno = 231
trigger3 = movecontact = 1
trigger4 = stateno = 233
trigger4 = movecontact = 1
trigger5 = stateno = 234
trigger5 = movecontact = 1
trigger6 = stateno = 200
trigger6 = movecontact = 1
trigger7 = stateno = 204
trigger7 = movecontact = 1
trigger8 = stateno = 210
trigger8 = movecontact = 1
trigger9 = stateno = 214
trigger9 = movecontact = 1

;---------------------------------------------------------------------------
;Crouch Kick 1
[State -1]
type = ChangeState
value = 233
triggerall = command = a
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 230
trigger2 = movecontact = 1
trigger3 = stateno = 200
trigger3 = movecontact = 1
trigger4 = stateno = 204
trigger4 = movecontact = 1
trigger5 = stateno = 210
trigger5 = movecontact = 1
trigger6 = stateno = 214
trigger6 = movecontact = 1

;---------------------------------------------------------------------------
;Crouch Kick 2
[State -1]
type = ChangeState
value = 234
triggerall = command = b
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 230
trigger2 = movecontact = 1
trigger3 = stateno = 233
trigger3 = movecontact = 1
trigger4 = stateno = 231
trigger4 = movecontact = 1

;---------------------------------------------------------------------------
;Crouch Kick 3
[State -1]
type = ChangeState
value = 235
triggerall = command = c
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 230
trigger2 = movecontact = 1
trigger3 = stateno = 231
trigger3 = movecontact = 1
trigger4 = stateno = 233
trigger4 = movecontact = 1
trigger5 = stateno = 234
trigger5 = movecontact = 1
trigger6 = stateno = 232
trigger6 = movecontact = 1

;---------------------------------------------------------------------------
;Jump Up Punch 1
[State -1]
type = ChangeState
value = 600
trigger1 = command = x
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger1 = vel X = 0

;---------------------------------------------------------------------------
;Jump Up Punch 2
[State -1]
type = ChangeState
value = 601
trigger1 = command = y
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger1 = vel X = 0

;---------------------------------------------------------------------------
;Jump Up Punch 3
[State -1]
type = ChangeState
value = 602
trigger1 = command = z
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger1 = vel X = 0

;---------------------------------------------------------------------------
;Jump Up Kick 1
[State -1]
type = ChangeState
value = 603
trigger1 = command = a
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger1 = vel X = 0

;---------------------------------------------------------------------------
;Jump Up Kick 2
[State -1]
type = ChangeState
value = 604
trigger1 = command = b
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger1 = vel X = 0

;---------------------------------------------------------------------------
;Jump Up Kick 3
[State -1]
type = ChangeState
value = 605
trigger1 = command = c
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger1 = vel X = 0

;---------------------------------------------------------------------------
;Jump Punch 1
[State -1]
type = ChangeState
value = 606
trigger1 = command = x
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger1 = vel X != 0

;---------------------------------------------------------------------------
;Jump Punch 2
[State -1]
type = ChangeState
value = 607
trigger1 = command = y
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger1 = vel X != 0

;---------------------------------------------------------------------------
;Jump Punch 3
[State -1]
type = ChangeState
value = 608
trigger1 = command = z
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger1 = vel X != 0

;---------------------------------------------------------------------------
;Jump Kick 1
[State -1]
type = ChangeState
value = 609
trigger1 = command = a
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger1 = vel X != 0

;---------------------------------------------------------------------------
;Jump Kick 2
[State -1]
type = ChangeState
value = 610
trigger1 = command = b
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger1 = vel X != 0

;---------------------------------------------------------------------------
;Jump Kick 3
[State -1]
type = ChangeState
value = 611
trigger1 = command = c
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger1 = vel X != 0

;---------------------------------------------------------------------------
;Taunt
[State -1]
type = ChangeState
value = 195
triggerall = command = s
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
