; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands are given below. Delete, add, or modify as you wish.

;-| Super Motions |--------------------------------------------------------
[Command]
name = PowerGeiser
command = ~D, DF, F, D, DF, F, b
time = 30

[Command]
name = Powerinf
command = ~30$B, F, a+b
time = 10

;[Command]
;name = DM2
;command = ~D, DF, F, D, DF, F, y
;time = 30
;-| Special Motions |------------------------------------------------------
;-----------------
; QCF
[Command]
name = PowerWave_A
command = ~D, DF, F, a

[Command]
name = PowerWave_b
command = ~D, DF, F, b

[Command]
name = TackleX
command = ~B,DB,D, DF, F, x

[Command]
name = TackleY
command = ~B,DB,D, DF, F, y

[Command]
name = PTX
command = ~D, DF, F, x

[Command]
name = PTy
command = ~D, DF, F, y

[Command]
name = PowerDunk_X
command = ~F, D, DF, x

[Command]
name = PowerDunk_Y
command = ~F, D, DF, y

; QCB
[Command]
name = PowerKa
command = ~D, DB, B, a

[Command]
name = PowerKb
command = ~D, DB, B, b

[Command]
name = QCB_c
command = ~D, DB, B, c

[Command]
name = CrackShot_x
command = ~D, DB, B, x

[Command]
name = CrackShot_y
command = ~D, DB, B, y

[Command]
name = QCB_z
command = ~D, DB, B, z

; Uppercut
[Command]
name = RTA
command = ~F, D, DF, a

[Command]
name = RTB
command = ~F, D, DF, b
;-| Double Tap |-----------------------------------------------------------
[Command]
name = FF       ;Required (do not remove)
command = F, F
time = 10

[Command]
name = BB       ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = recovery ;Required (do not remove)
command = a+b
time = 1

[Command]
name = ab
command = a+b
time = 1

[Command]
name = by
command = b+y
time = 1

;--------------------------------
;Roll
;--------------------------------
[Command]
name = fwd_z
command = /F,z
time = 1

[Command]
name = DF_z
command = /DF,z
time = 1

[Command]
name = back_z
command = /B,z
time = 1

[Command]
name = DB_z
command = /DB,z
time = 1
;--------------------------------

[Command]
name = DF_b
command = /DF, b
time = 1

[Command]
name = fwd_a
command = /F,/$a
time = 1

[Command]
name = fwd_b
command = /F,b
time = 1

[Command]
name = fwd_c
command = /F,c
time = 1

[Command]
name = fwd_x
command = /F,x
time = 1

[Command]
name = fwd_y
command = /F,y
time = 1

[Command]
name = back_a
command = /B,a
time = 1

[Command]
name = back_b
command = /B,b
time = 1

[Command]
name = down_a
command = /$D,a
time = 1

[Command]
name = fwd_ab
command = /F, a+b
time = 1

[Command]
name = back_ab
command = /B, a+b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = a
command = a
time = 1

[Command]
name = b
command = b
time = 1

[Command]
name = c
command = c
time = 1

[Command]
name = x
command = x
time = 1

[Command]
name = y
command = y
time = 1

[Command]
name = z
command = z
time = 1

[Command]
name = hold_a
command = /$a
time = 1

[Command]
name = hold_x
command = /$x
time = 1

[Command]
name = hold_b
command = /$b
time = 1
;-| Hold Dir |--------------------------------------------------------------
[Command]
name = holdfwd  ;Required (do not remove)
command = /$F
time = 1

[Command]
name = holdback ;Required (do not remove)
command = /$B
time = 1

[Command]
name = holdup   ;Required (do not remove)
command = /$U
time = 1

[Command]
name = holddown ;Required (do not remove)
command = /$D
time = 1


;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in. 


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]
;===========================================================================
;Power Inferno
[State -1]
type = ChangeState
value = 1200
triggerall = command = Powerinf
triggerall = power >= 1000 ;Level 1
trigger1 = statetype != A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;TripleGeiser 
[State -1]
type = ChangeState
value = 1300
triggerall = command = PowerGeiser
triggerall = power = 3000 ;Level 1
trigger1 = statetype != A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;PowerGeiser
[State -1]
type = ChangeState
value = 1105
triggerall = command = PowerGeiser
triggerall = power >= 1000 ;Level 1
trigger1 = statetype != A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;DM2
;[State -1]
;type = ChangeState
;value = 3000
;triggerall = command = DM2
;triggerall = power >= 1000 ;Level 1
;trigger1 = statetype != A
;trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;PowerDunk_X
[State -1]
type = ChangeState
value = 1000
triggerall = command = PowerDunk_X
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;PowerDunk_Y
[State -1]
type = ChangeState
value = 1005
triggerall = command = PowerDunk_Y
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;TackleX
[State -1]
type = ChangeState
value = 325
triggerall = command = TackleX
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;TackleY
[State -1]
type = ChangeState
value = 325
triggerall = command = TackleY
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;RTA
[State -1]
type = ChangeState
value = 1100
triggerall = command = RTA
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;RTB
[State -1]
type = ChangeState
value = 1103
triggerall = command = RTB
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;PTx
[State -1]
type = ChangeState
value = 1020
triggerall = command = PTX
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;PTy
[State -1]
type = ChangeState
value = 1021
triggerall = command = PTy
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;PowerKa
[State -1]
type = ChangeState
value = 1050
triggerall = command = PowerKa
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;PowerKb
[State -1]
type = ChangeState
value = 1051
triggerall = command = PowerKb
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;CrackShot_x
[State -1]
type = ChangeState
value = 1057
triggerall = command = CrackShot_x
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;CrackShot_y
[State -1]
type = ChangeState
value = 1070
triggerall = command = CrackShot_y
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;PowerWave_A
[State -1]
type = ChangeState
value = 1030
triggerall = command = PowerWave_A
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;PowerWave_b
[State -1]
type = ChangeState
value = 1040
triggerall = command = PowerWave_b
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Stand_C
[State -1]
type = ChangeState
value = 320
triggerall = command = c
trigger1 = statetype = s
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Charge AX
[State -1]
type = ChangeState
value = 890
triggerall = power < 3000
trigger1 = command = hold_a
trigger1 = command = hold_x
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;ROLLFWD
[State -1]
type = ChangeState
value = 840
trigger1 = command = fwd_z
trigger1 = statetype = s
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;ROLLBWD
[State -1]
type = ChangeState
value = 841
trigger1 = command = back_z
trigger1 = statetype = s
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Esc
[State -1]
type = ChangeState
value = 920
triggerall = command = z
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;RunFwd
[State -1]
type = ChangeState
value = 100
trigger1 = command = FF
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;RunBack
[State -1]
type = ChangeState
value = 105
trigger1 = command = BB
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Stand_Throw (close dir+b)
; Complicated? Skip the throws and look at stand_a, etc, first.
; This is disabled right now. Remove the "null;" below when you
; want to use it.
[State -1]
type = ChangeState
value = 900
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = p2bodydist X < 5 ;Near P2
trigger1 = command = fwd_b   ;p2 stand
trigger1 = stateno != 100    ;Not running
trigger1 = p2statetype = S
trigger1 = p2movetype != H
trigger2 = command = fwd_b   ;p2 crouch
trigger2 = stateno != 100    ;Not running
trigger2 = p2statetype = C
trigger2 = p2movetype != H
;---------------------------------------------------------------------------
;Stand_Throw (close dir+y)
; Complicated? Skip the throws and look at stand_a, etc, first.
; This is disabled right now. Remove the "null;" below when you
; want to use it.
[State -1]
type = ChangeState
value = 902
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = p2bodydist X < 5 ;Near P2
trigger1 = command = fwd_y   ;p2 stand
trigger1 = stateno != 100    ;Not running
trigger1 = p2statetype = S
trigger1 = p2movetype != H
trigger2 = command = fwd_y   ;p2 crouch
trigger2 = stateno != 100    ;Not running
trigger2 = p2statetype = C
trigger2 = p2movetype != H
;---------------------------------------------------------------------------
;Air_Throw1 (close dir+b)
; This is disabled right now. Remove the "null;" below when you
; want to use it.
[State -1]
type = null; ChangeState
value = 950
triggerall = statetype = A
triggerall = ctrl = 1
triggerall = p2bodydist X < 9
triggerall = p2bodydist Y > -22
triggerall = p2bodydist Y < 22
triggerall = p2statetype = A
triggerall = p2movetype != H
trigger1 = command = fwd_b
trigger2 = command = back_b
;---------------------------------------------------------------------------
;Foward A
[State -1]
type = ChangeState
value = 203
triggerall = command = fwd_a
triggerall = command != holddown  
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 215
trigger2 = movecontact = 1
trigger3 = stateno = 202
trigger3 = movecontact = 1
trigger4 = stateno = 235
trigger4 = movecontact = 1
trigger5 = stateno = 400
trigger5 = movecontact = 1
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 240
trigger7 = movecontact = 1
trigger8 = stateno = 430
trigger8 = movecontact = 1
trigger9 = stateno = 231
trigger9 = movecontact = 1

;Stand_A
[State -1]
type = ChangeState
value = 200
triggerall = command = a
triggerall = P2bodydist X > 30
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 230 ;Stand_X
trigger2 = movecontact = 1

;Stand_A (close)
[State -1]
type = ChangeState
value = 202
triggerall = command = a
triggerall = P2bodydist X <= 30
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200 ;Stand_A
trigger2 = movecontact = 1
;---------------------------------------------------------------------------
;Stand_B
[State -1]
type = ChangeState
value = 210
triggerall = command = b
triggerall = P2bodydist X > 20
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = time >= 8

;Stand_B (close)
[State -1]
type = ChangeState
value = 215
triggerall = command = b
triggerall = P2bodydist X <= 20
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 202 ;Stand_X
trigger2 = movecontact = 1

;DF_b
[State -1]
type = ChangeState
value = 231
triggerall = command = DF_b
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 215
trigger2 = movecontact = 1
trigger3 = stateno = 202
trigger3 = movecontact = 1
trigger4 = stateno = 235
trigger4 = movecontact = 1
trigger5 = stateno = 400
trigger5 = movecontact = 1
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 240
trigger7 = movecontact = 1
trigger8 = stateno = 430
trigger8 = movecontact = 1
;---------------------------------------------------------------------------
;Stand_X
[State -1]
type = ChangeState
value = 230
triggerall = command = x         
triggerall = command != holddown  
triggerall = P2bodydist X > 20
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = time >= 7

;Stand_X (close)
[State -1]
type = ChangeState
value = 235
triggerall = command = x
triggerall = command != holddown
triggerall = P2bodydist X <= 20
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Stand_Y
[State -1]
type = ChangeState
value = 240
triggerall = command = y      
triggerall = command != holddown  
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = time >= 7
trigger3 = stateno = 210
;---------------------------------------------------------------------------
;Crouch_A
[State -1]
type = ChangeState
value = 400
triggerall = command = a
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Crouch_B
[State -1]
type = ChangeState
value = 410
triggerall = command = b
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Crouch_X
[State -1]
type = ChangeState
value = 430
triggerall = command = x
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Crouch_Y
[State -1]
type = ChangeState
value = 440
triggerall = command = y
triggerall = command = holddown
trigger1 = statetype = C
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Jump_A
[State -1]
type = ChangeState
value = 600
trigger1 = command = a
trigger1 = statetype = A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Jump_B
[State -1]
type = ChangeState
value = 610
trigger1 = command = b
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jump_X
[State -1]
type = ChangeState
value = 630
trigger1 = command = x
trigger1 = statetype = A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Jump_Y
[State -1]
type = ChangeState
value = 640
trigger1 = command = y
trigger1 = statetype = A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------